from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.TopoDS import *
from OCC.Core.TopTools import *
from OCC.Core.Message import *
from OCC.Core.IntTools import *
from OCC.Core.BOPDS import *
from OCC.Core.Bnd import *
from OCC.Core.gp import *
from OCC.Core.BRepTools import *
from OCC.Core.BOPTools import *
from OCC.Core.TopAbs import *

#the following typedef cannot be wrapped as is
BOPAlgo_ListIteratorOfListOfCheckResult = NewType('BOPAlgo_ListIteratorOfListOfCheckResult', Any)
BOPAlgo_PArgumentAnalyzer = NewType('BOPAlgo_PArgumentAnalyzer', BOPAlgo_ArgumentAnalyzer)
BOPAlgo_PBOP = NewType('BOPAlgo_PBOP', BOPAlgo_BOP)
BOPAlgo_PBuilder = NewType('BOPAlgo_PBuilder', BOPAlgo_Builder)
BOPAlgo_PPaveFiller = NewType('BOPAlgo_PPaveFiller', BOPAlgo_PaveFiller)
BOPAlgo_PSection = NewType('BOPAlgo_PSection', BOPAlgo_Section)
BOPAlgo_PWireEdgeSet = NewType('BOPAlgo_PWireEdgeSet', BOPAlgo_WireEdgeSet)

class BOPAlgo_ListOfCheckResult:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> BOPAlgo_CheckResult: ...
    def Last(self) -> BOPAlgo_CheckResult: ...
    def Append(self, theItem: BOPAlgo_CheckResult) -> BOPAlgo_CheckResult: ...
    def Prepend(self, theItem: BOPAlgo_CheckResult) -> BOPAlgo_CheckResult: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> BOPAlgo_CheckResult: ...
    def SetValue(self, theIndex: int, theValue: BOPAlgo_CheckResult) -> None: ...

class BOPAlgo_CheckStatus(IntEnum):
	BOPAlgo_CheckUnknown: int = ...
	BOPAlgo_BadType: int = ...
	BOPAlgo_SelfIntersect: int = ...
	BOPAlgo_TooSmallEdge: int = ...
	BOPAlgo_NonRecoverableFace: int = ...
	BOPAlgo_IncompatibilityOfVertex: int = ...
	BOPAlgo_IncompatibilityOfEdge: int = ...
	BOPAlgo_IncompatibilityOfFace: int = ...
	BOPAlgo_OperationAborted: int = ...
	BOPAlgo_GeomAbs_C0: int = ...
	BOPAlgo_InvalidCurveOnSurface: int = ...
	BOPAlgo_NotValid: int = ...
BOPAlgo_CheckUnknown = BOPAlgo_CheckStatus.BOPAlgo_CheckUnknown
BOPAlgo_BadType = BOPAlgo_CheckStatus.BOPAlgo_BadType
BOPAlgo_SelfIntersect = BOPAlgo_CheckStatus.BOPAlgo_SelfIntersect
BOPAlgo_TooSmallEdge = BOPAlgo_CheckStatus.BOPAlgo_TooSmallEdge
BOPAlgo_NonRecoverableFace = BOPAlgo_CheckStatus.BOPAlgo_NonRecoverableFace
BOPAlgo_IncompatibilityOfVertex = BOPAlgo_CheckStatus.BOPAlgo_IncompatibilityOfVertex
BOPAlgo_IncompatibilityOfEdge = BOPAlgo_CheckStatus.BOPAlgo_IncompatibilityOfEdge
BOPAlgo_IncompatibilityOfFace = BOPAlgo_CheckStatus.BOPAlgo_IncompatibilityOfFace
BOPAlgo_OperationAborted = BOPAlgo_CheckStatus.BOPAlgo_OperationAborted
BOPAlgo_GeomAbs_C0 = BOPAlgo_CheckStatus.BOPAlgo_GeomAbs_C0
BOPAlgo_InvalidCurveOnSurface = BOPAlgo_CheckStatus.BOPAlgo_InvalidCurveOnSurface
BOPAlgo_NotValid = BOPAlgo_CheckStatus.BOPAlgo_NotValid

class BOPAlgo_Operation(IntEnum):
	BOPAlgo_COMMON: int = ...
	BOPAlgo_FUSE: int = ...
	BOPAlgo_CUT: int = ...
	BOPAlgo_CUT21: int = ...
	BOPAlgo_SECTION: int = ...
	BOPAlgo_UNKNOWN: int = ...
BOPAlgo_COMMON = BOPAlgo_Operation.BOPAlgo_COMMON
BOPAlgo_FUSE = BOPAlgo_Operation.BOPAlgo_FUSE
BOPAlgo_CUT = BOPAlgo_Operation.BOPAlgo_CUT
BOPAlgo_CUT21 = BOPAlgo_Operation.BOPAlgo_CUT21
BOPAlgo_SECTION = BOPAlgo_Operation.BOPAlgo_SECTION
BOPAlgo_UNKNOWN = BOPAlgo_Operation.BOPAlgo_UNKNOWN

class BOPAlgo_GlueEnum(IntEnum):
	BOPAlgo_GlueOff: int = ...
	BOPAlgo_GlueShift: int = ...
	BOPAlgo_GlueFull: int = ...
BOPAlgo_GlueOff = BOPAlgo_GlueEnum.BOPAlgo_GlueOff
BOPAlgo_GlueShift = BOPAlgo_GlueEnum.BOPAlgo_GlueShift
BOPAlgo_GlueFull = BOPAlgo_GlueEnum.BOPAlgo_GlueFull

class BOPAlgo_CheckResult:
	def __init__(self) -> None: ...
	def AddFaultyShape1(self, TheShape: TopoDS_Shape) -> None: ...
	def AddFaultyShape2(self, TheShape: TopoDS_Shape) -> None: ...
	def GetCheckStatus(self) -> BOPAlgo_CheckStatus: ...
	def GetFaultyShapes1(self) -> TopTools_ListOfShape: ...
	def GetFaultyShapes2(self) -> TopTools_ListOfShape: ...
	def GetMaxDistance1(self) -> float: ...
	def GetMaxDistance2(self) -> float: ...
	def GetMaxParameter1(self) -> float: ...
	def GetMaxParameter2(self) -> float: ...
	def GetShape1(self) -> TopoDS_Shape: ...
	def GetShape2(self) -> TopoDS_Shape: ...
	def SetCheckStatus(self, TheStatus: BOPAlgo_CheckStatus) -> None: ...
	def SetMaxDistance1(self, theDist: float) -> None: ...
	def SetMaxDistance2(self, theDist: float) -> None: ...
	def SetMaxParameter1(self, thePar: float) -> None: ...
	def SetMaxParameter2(self, thePar: float) -> None: ...
	def SetShape1(self, TheShape: TopoDS_Shape) -> None: ...
	def SetShape2(self, TheShape: TopoDS_Shape) -> None: ...

class BOPAlgo_Options:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theAllocator: NCollection_BaseAllocator) -> None: ...
	def AddError(self, theAlert: Message_Alert) -> None: ...
	def AddWarning(self, theAlert: Message_Alert) -> None: ...
	def Allocator(self) -> NCollection_BaseAllocator: ...
	def Clear(self) -> None: ...
	def ClearWarnings(self) -> None: ...
	def FuzzyValue(self) -> float: ...
	@staticmethod
	def GetParallelMode() -> bool: ...
	def GetReport(self) -> Message_Report: ...
	def HasError(self, theType: Standard_Type) -> bool: ...
	def HasErrors(self) -> bool: ...
	def HasWarning(self, theType: Standard_Type) -> bool: ...
	def HasWarnings(self) -> bool: ...
	def RunParallel(self) -> bool: ...
	def SetFuzzyValue(self, theFuzz: float) -> None: ...
	@staticmethod
	def SetParallelMode(theNewMode: bool) -> None: ...
	def SetProgressIndicator(self, theProgress: Message_ProgressScope) -> None: ...
	def SetRunParallel(self, theFlag: bool) -> None: ...
	def SetUseOBB(self, theUseOBB: bool) -> None: ...
	def UseOBB(self) -> bool: ...

class BOPAlgo_SectionAttribute:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theAproximation: bool, thePCurveOnS1: bool, thePCurveOnS2: bool) -> None: ...
	@overload
	def Approximation(self, theApprox: bool) -> None: ...
	@overload
	def Approximation(self) -> bool: ...
	@overload
	def PCurveOnS1(self, thePCurveOnS1: bool) -> None: ...
	@overload
	def PCurveOnS1(self) -> bool: ...
	@overload
	def PCurveOnS2(self, thePCurveOnS2: bool) -> None: ...
	@overload
	def PCurveOnS2(self) -> bool: ...

class BOPAlgo_Tools:
	@staticmethod
	def ClassifyFaces(theFaces: TopTools_ListOfShape, theSolids: TopTools_ListOfShape, theRunParallel: bool, theContext: IntTools_Context, theInParts: TopTools_IndexedDataMapOfShapeListOfShape, theShapeBoxMap: Optional[TopTools_DataMapOfShapeBox] = TopTools_DataMapOfShapeBox(), theSolidsIF: Optional[TopTools_DataMapOfShapeListOfShape] = TopTools_DataMapOfShapeListOfShape()) -> None: ...
	@staticmethod
	def ComputeToleranceOfCB(theCB: BOPDS_CommonBlock, theDS: BOPDS_PDS, theContext: IntTools_Context) -> float: ...
	@staticmethod
	def EdgesToWires(theEdges: TopoDS_Shape, theWires: TopoDS_Shape, theShared: Optional[bool] = False, theAngTol: Optional[float] = 1e-8) -> int: ...
	@staticmethod
	def FillInternals(theSolids: TopTools_ListOfShape, theParts: TopTools_ListOfShape, theImages: TopTools_DataMapOfShapeListOfShape, theContext: IntTools_Context) -> None: ...
	@staticmethod
	def IntersectVertices(theVertices: TopTools_IndexedDataMapOfShapeReal, theFuzzyValue: float, theChains: TopTools_ListOfListOfShape) -> None: ...
	@overload
	@staticmethod
	def PerformCommonBlocks(theMBlocks: BOPDS_IndexedDataMapOfPaveBlockListOfPaveBlock, theAllocator: NCollection_BaseAllocator, theDS: BOPDS_PDS, theContext: Optional[IntTools_Context] = IntTools_Context()) -> None: ...
	@overload
	@staticmethod
	def PerformCommonBlocks(theMBlocks: BOPDS_IndexedDataMapOfPaveBlockListOfInteger, theAllocator: NCollection_BaseAllocator, pDS: BOPDS_PDS, theContext: Optional[IntTools_Context] = IntTools_Context()) -> None: ...
	@staticmethod
	def TrsfToPoint(theBox1: Bnd_Box, theBox2: Bnd_Box, theTrsf: gp_Trsf, thePoint: Optional[gp_Pnt] = gp_Pnt(0.0,0.0,0.0), theCriteria: Optional[float] = 1e+5) -> bool: ...
	@staticmethod
	def WiresToFaces(theWires: TopoDS_Shape, theFaces: TopoDS_Shape, theAngTol: Optional[float] = 1e-8) -> bool: ...

class BOPAlgo_WireEdgeSet:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theAllocator: NCollection_BaseAllocator) -> None: ...
	def AddShape(self, sS: TopoDS_Shape) -> None: ...
	def AddStartElement(self, sS: TopoDS_Shape) -> None: ...
	def Clear(self) -> None: ...
	def Face(self) -> TopoDS_Face: ...
	def SetFace(self, aF: TopoDS_Face) -> None: ...
	def Shapes(self) -> TopTools_ListOfShape: ...
	def StartElements(self) -> TopTools_ListOfShape: ...

class BOPAlgo_Algo(BOPAlgo_Options):
	def Perform(self) -> None: ...

class BOPAlgo_MakeConnected(BOPAlgo_Options):
	def __init__(self) -> None: ...
	def AddArgument(self, theS: TopoDS_Shape) -> None: ...
	def Arguments(self) -> TopTools_ListOfShape: ...
	def Clear(self) -> None: ...
	def ClearRepetitions(self) -> None: ...
	def GetModified(self, theS: TopoDS_Shape) -> TopTools_ListOfShape: ...
	def GetOrigins(self, theS: TopoDS_Shape) -> TopTools_ListOfShape: ...
	def History(self) -> BRepTools_History: ...
	def MaterialsOnNegativeSide(self, theS: TopoDS_Shape) -> TopTools_ListOfShape: ...
	def MaterialsOnPositiveSide(self, theS: TopoDS_Shape) -> TopTools_ListOfShape: ...
	def Perform(self) -> None: ...
	def PeriodicShape(self) -> TopoDS_Shape: ...
	def PeriodicityTool(self) -> BOPAlgo_MakePeriodic: ...
	def RepeatShape(self, theDirectionID: int, theTimes: int) -> None: ...
	def SetArguments(self, theArgs: TopTools_ListOfShape) -> None: ...
	def Shape(self) -> TopoDS_Shape: ...

class BOPAlgo_MakePeriodic(BOPAlgo_Options):
	def __init__(self) -> None: ...
	def Clear(self) -> None: ...
	def ClearRepetitions(self) -> None: ...
	def GetTwins(self, theS: TopoDS_Shape) -> TopTools_ListOfShape: ...
	def History(self) -> BRepTools_History: ...
	def IsInputTrimmed(self, theDirectionID: int) -> bool: ...
	def IsInputXTrimmed(self) -> bool: ...
	def IsInputYTrimmed(self) -> bool: ...
	def IsInputZTrimmed(self) -> bool: ...
	def IsPeriodic(self, theDirectionID: int) -> bool: ...
	def IsXPeriodic(self) -> bool: ...
	def IsYPeriodic(self) -> bool: ...
	def IsZPeriodic(self) -> bool: ...
	def MakePeriodic(self, theDirectionID: int, theIsPeriodic: bool, thePeriod: Optional[float] = 0.0) -> None: ...
	def MakeXPeriodic(self, theIsPeriodic: bool, thePeriod: Optional[float] = 0.0) -> None: ...
	def MakeYPeriodic(self, theIsPeriodic: bool, thePeriod: Optional[float] = 0.0) -> None: ...
	def MakeZPeriodic(self, theIsPeriodic: bool, thePeriod: Optional[float] = 0.0) -> None: ...
	def Perform(self) -> None: ...
	def Period(self, theDirectionID: int) -> float: ...
	def PeriodFirst(self, theDirectionID: int) -> float: ...
	def PeriodicityParameters(self) -> False: ...
	def RepeatShape(self, theDirectionID: int, theTimes: int) -> TopoDS_Shape: ...
	def RepeatedShape(self) -> TopoDS_Shape: ...
	def SetShape(self, theShape: TopoDS_Shape) -> None: ...
	def SetTrimmed(self, theDirectionID: int, theIsTrimmed: bool, theFirst: Optional[float] = 0.0) -> None: ...
	def SetXTrimmed(self, theIsTrimmed: bool, theFirst: Optional[bool] = 0.0) -> None: ...
	def SetYTrimmed(self, theIsTrimmed: bool, theFirst: Optional[bool] = 0.0) -> None: ...
	def SetZTrimmed(self, theIsTrimmed: bool, theFirst: Optional[bool] = 0.0) -> None: ...
	def Shape(self) -> TopoDS_Shape: ...
	@staticmethod
	def ToDirectionID(theDirectionID: int) -> int: ...
	def XPeriod(self) -> float: ...
	def XPeriodFirst(self) -> float: ...
	def XRepeat(self, theTimes: int) -> TopoDS_Shape: ...
	def YPeriod(self) -> float: ...
	def YPeriodFirst(self) -> float: ...
	def YRepeat(self, theTimes: int) -> TopoDS_Shape: ...
	def ZPeriod(self) -> float: ...
	def ZPeriodFirst(self) -> float: ...
	def ZRepeat(self, theTimes: int) -> TopoDS_Shape: ...

class BOPAlgo_ArgumentAnalyzer(BOPAlgo_Algo):
	def __init__(self) -> None: ...
	def GetArgumentTypeMode(self) -> bool: ...
	def SetArgumentTypeMode(self, value: bool) -> None: ...
	def GetContinuityMode(self) -> bool: ...
	def SetContinuityMode(self, value: bool) -> None: ...
	def GetCurveOnSurfaceMode(self) -> bool: ...
	def SetCurveOnSurfaceMode(self, value: bool) -> None: ...
	def GetCheckResult(self) -> BOPAlgo_ListOfCheckResult: ...
	def GetShape1(self) -> TopoDS_Shape: ...
	def GetShape2(self) -> TopoDS_Shape: ...
	def HasFaulty(self) -> bool: ...
	def GetMergeEdgeMode(self) -> bool: ...
	def SetMergeEdgeMode(self, value: bool) -> None: ...
	def GetMergeVertexMode(self) -> bool: ...
	def SetMergeVertexMode(self, value: bool) -> None: ...
	def OperationType(self) -> BOPAlgo_Operation: ...
	def Perform(self) -> None: ...
	def GetRebuildFaceMode(self) -> bool: ...
	def SetRebuildFaceMode(self, value: bool) -> None: ...
	def GetSelfInterMode(self) -> bool: ...
	def SetSelfInterMode(self, value: bool) -> None: ...
	def SetShape1(self, TheShape: TopoDS_Shape) -> None: ...
	def SetShape2(self, TheShape: TopoDS_Shape) -> None: ...
	def GetSmallEdgeMode(self) -> bool: ...
	def SetSmallEdgeMode(self, value: bool) -> None: ...
	def GetStopOnFirstFaulty(self) -> bool: ...
	def SetStopOnFirstFaulty(self, value: bool) -> None: ...
	def GetTangentMode(self) -> bool: ...
	def SetTangentMode(self, value: bool) -> None: ...

class BOPAlgo_BuilderArea(BOPAlgo_Algo):
	def Areas(self) -> TopTools_ListOfShape: ...
	def IsAvoidInternalShapes(self) -> bool: ...
	def Loops(self) -> TopTools_ListOfShape: ...
	def SetAvoidInternalShapes(self, theAvoidInternal: bool) -> None: ...
	def SetContext(self, theContext: IntTools_Context) -> None: ...
	def SetShapes(self, theLS: TopTools_ListOfShape) -> None: ...
	def Shapes(self) -> TopTools_ListOfShape: ...

class BOPAlgo_BuilderShape(BOPAlgo_Algo):
	def Generated(self, theS: TopoDS_Shape) -> TopTools_ListOfShape: ...
	def HasDeleted(self) -> bool: ...
	def HasGenerated(self) -> bool: ...
	def HasHistory(self) -> bool: ...
	def HasModified(self) -> bool: ...
	def History(self) -> BRepTools_History: ...
	def IsDeleted(self, theS: TopoDS_Shape) -> bool: ...
	def Modified(self, theS: TopoDS_Shape) -> TopTools_ListOfShape: ...
	def SetToFillHistory(self, theHistFlag: bool) -> None: ...
	def Shape(self) -> TopoDS_Shape: ...

class BOPAlgo_PaveFiller(BOPAlgo_Algo):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theAllocator: NCollection_BaseAllocator) -> None: ...
	def AddArgument(self, theShape: TopoDS_Shape) -> None: ...
	def Arguments(self) -> TopTools_ListOfShape: ...
	def Context(self) -> IntTools_Context: ...
	def DS(self) -> BOPDS_DS: ...
	def Glue(self) -> BOPAlgo_GlueEnum: ...
	def IsAvoidBuildPCurve(self) -> bool: ...
	def NonDestructive(self) -> bool: ...
	def PDS(self) -> BOPDS_PDS: ...
	def Perform(self) -> None: ...
	def SetArguments(self, theLS: TopTools_ListOfShape) -> None: ...
	def SetAvoidBuildPCurve(self, theValue: bool) -> None: ...
	def SetGlue(self, theGlue: BOPAlgo_GlueEnum) -> None: ...
	def SetNonDestructive(self, theFlag: bool) -> None: ...
	def SetSectionAttribute(self, theSecAttr: BOPAlgo_SectionAttribute) -> None: ...

class BOPAlgo_ShellSplitter(BOPAlgo_Algo):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theAllocator: NCollection_BaseAllocator) -> None: ...
	def AddStartElement(self, theS: TopoDS_Shape) -> None: ...
	def Perform(self) -> None: ...
	def Shells(self) -> TopTools_ListOfShape: ...
	@staticmethod
	def SplitBlock(theCB: BOPTools_ConnexityBlock) -> None: ...
	def StartElements(self) -> TopTools_ListOfShape: ...

class BOPAlgo_WireSplitter(BOPAlgo_Algo):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theAllocator: NCollection_BaseAllocator) -> None: ...
	def Context(self) -> IntTools_Context: ...
	@staticmethod
	def MakeWire(theLE: TopTools_ListOfShape, theW: TopoDS_Wire) -> None: ...
	def Perform(self) -> None: ...
	def SetContext(self, theContext: IntTools_Context) -> None: ...
	def SetWES(self, theWES: BOPAlgo_WireEdgeSet) -> None: ...
	@staticmethod
	def SplitBlock(theF: TopoDS_Face, theCB: BOPTools_ConnexityBlock, theContext: IntTools_Context) -> None: ...
	def WES(self) -> BOPAlgo_WireEdgeSet: ...

class BOPAlgo_Builder(BOPAlgo_BuilderShape):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theAllocator: NCollection_BaseAllocator) -> None: ...
	def AddArgument(self, theShape: TopoDS_Shape) -> None: ...
	def Arguments(self) -> TopTools_ListOfShape: ...
	@overload
	def BuildBOP(self, theObjects: TopTools_ListOfShape, theObjState: TopAbs_State, theTools: TopTools_ListOfShape, theToolsState: TopAbs_State, theReport: Optional[Message_Report] = None) -> None: ...
	@overload
	def BuildBOP(self, theObjects: TopTools_ListOfShape, theTools: TopTools_ListOfShape, theOperation: BOPAlgo_Operation, theReport: Optional[Message_Report] = None) -> None: ...
	def CheckInverted(self) -> bool: ...
	def Clear(self) -> None: ...
	def Context(self) -> IntTools_Context: ...
	def Glue(self) -> BOPAlgo_GlueEnum: ...
	def Images(self) -> TopTools_DataMapOfShapeListOfShape: ...
	def NonDestructive(self) -> bool: ...
	def Origins(self) -> TopTools_DataMapOfShapeListOfShape: ...
	def PDS(self) -> BOPDS_PDS: ...
	def PPaveFiller(self) -> BOPAlgo_PPaveFiller: ...
	def Perform(self) -> None: ...
	def PerformWithFiller(self, theFiller: BOPAlgo_PaveFiller) -> None: ...
	def SetArguments(self, theLS: TopTools_ListOfShape) -> None: ...
	def SetCheckInverted(self, theCheck: bool) -> None: ...
	def SetGlue(self, theGlue: BOPAlgo_GlueEnum) -> None: ...
	def SetNonDestructive(self, theFlag: bool) -> None: ...
	def ShapesSD(self) -> TopTools_DataMapOfShapeShape: ...

class BOPAlgo_BuilderFace(BOPAlgo_BuilderArea):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theAllocator: NCollection_BaseAllocator) -> None: ...
	def Face(self) -> TopoDS_Face: ...
	def Orientation(self) -> TopAbs_Orientation: ...
	def Perform(self) -> None: ...
	def SetFace(self, theFace: TopoDS_Face) -> None: ...

class BOPAlgo_BuilderSolid(BOPAlgo_BuilderArea):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theAllocator: NCollection_BaseAllocator) -> None: ...
	def GetBoxesMap(self) -> TopTools_DataMapOfShapeBox: ...
	def Perform(self) -> None: ...

class BOPAlgo_CheckerSI(BOPAlgo_PaveFiller):
	def __init__(self) -> None: ...
	def Perform(self) -> None: ...
	def SetLevelOfCheck(self, theLevel: int) -> None: ...

class BOPAlgo_RemoveFeatures(BOPAlgo_BuilderShape):
	def __init__(self) -> None: ...
	def AddFaceToRemove(self, theFace: TopoDS_Shape) -> None: ...
	def AddFacesToRemove(self, theFaces: TopTools_ListOfShape) -> None: ...
	def Clear(self) -> None: ...
	def FacesToRemove(self) -> TopTools_ListOfShape: ...
	def InputShape(self) -> TopoDS_Shape: ...
	def Perform(self) -> None: ...
	def SetShape(self, theShape: TopoDS_Shape) -> None: ...

class BOPAlgo_CellsBuilder(BOPAlgo_Builder):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theAllocator: NCollection_BaseAllocator) -> None: ...
	def AddAllToResult(self, theMaterial: Optional[int] = 0, theUpdate: Optional[bool] = False) -> None: ...
	def AddToResult(self, theLSToTake: TopTools_ListOfShape, theLSToAvoid: TopTools_ListOfShape, theMaterial: Optional[int] = 0, theUpdate: Optional[bool] = False) -> None: ...
	def Clear(self) -> None: ...
	def GetAllParts(self) -> TopoDS_Shape: ...
	def MakeContainers(self) -> None: ...
	def RemoveAllFromResult(self) -> None: ...
	def RemoveFromResult(self, theLSToTake: TopTools_ListOfShape, theLSToAvoid: TopTools_ListOfShape) -> None: ...
	def RemoveInternalBoundaries(self) -> None: ...

class BOPAlgo_MakerVolume(BOPAlgo_Builder):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theAllocator: NCollection_BaseAllocator) -> None: ...
	def Box(self) -> TopoDS_Solid: ...
	def Clear(self) -> None: ...
	def Faces(self) -> TopTools_ListOfShape: ...
	def IsAvoidInternalShapes(self) -> bool: ...
	def IsIntersect(self) -> bool: ...
	def Perform(self) -> None: ...
	def SetAvoidInternalShapes(self, theAvoidInternal: bool) -> None: ...
	def SetIntersect(self, bIntersect: bool) -> None: ...

class BOPAlgo_Section(BOPAlgo_Builder):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theAllocator: NCollection_BaseAllocator) -> None: ...

class BOPAlgo_ToolsProvider(BOPAlgo_Builder):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theAllocator: NCollection_BaseAllocator) -> None: ...
	def AddTool(self, theShape: TopoDS_Shape) -> None: ...
	def Clear(self) -> None: ...
	def SetTools(self, theShapes: TopTools_ListOfShape) -> None: ...
	def Tools(self) -> TopTools_ListOfShape: ...

class BOPAlgo_BOP(BOPAlgo_ToolsProvider):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theAllocator: NCollection_BaseAllocator) -> None: ...
	def Clear(self) -> None: ...
	def Operation(self) -> BOPAlgo_Operation: ...
	def Perform(self) -> None: ...
	def SetOperation(self, theOperation: BOPAlgo_Operation) -> None: ...

class BOPAlgo_Splitter(BOPAlgo_ToolsProvider):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theAllocator: NCollection_BaseAllocator) -> None: ...
	def Perform(self) -> None: ...

# harray1 classes
# harray2 classes
# hsequence classes

BOPAlgo_Options_GetParallelMode = BOPAlgo_Options.GetParallelMode
BOPAlgo_Options_SetParallelMode = BOPAlgo_Options.SetParallelMode
BOPAlgo_Tools_ClassifyFaces = BOPAlgo_Tools.ClassifyFaces
BOPAlgo_Tools_ComputeToleranceOfCB = BOPAlgo_Tools.ComputeToleranceOfCB
BOPAlgo_Tools_EdgesToWires = BOPAlgo_Tools.EdgesToWires
BOPAlgo_Tools_FillInternals = BOPAlgo_Tools.FillInternals
BOPAlgo_Tools_IntersectVertices = BOPAlgo_Tools.IntersectVertices
BOPAlgo_Tools_PerformCommonBlocks = BOPAlgo_Tools.PerformCommonBlocks
BOPAlgo_Tools_PerformCommonBlocks = BOPAlgo_Tools.PerformCommonBlocks
BOPAlgo_Tools_TrsfToPoint = BOPAlgo_Tools.TrsfToPoint
BOPAlgo_Tools_WiresToFaces = BOPAlgo_Tools.WiresToFaces
BOPAlgo_MakePeriodic_ToDirectionID = BOPAlgo_MakePeriodic.ToDirectionID
BOPAlgo_ShellSplitter_SplitBlock = BOPAlgo_ShellSplitter.SplitBlock
BOPAlgo_WireSplitter_MakeWire = BOPAlgo_WireSplitter.MakeWire
BOPAlgo_WireSplitter_SplitBlock = BOPAlgo_WireSplitter.SplitBlock



from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.Transfer import *
from OCC.Core.StepRepr import *
from OCC.Core.gp import *
from OCC.Core.StepGeom import *
from OCC.Core.Message import *
from OCC.Core.TopoDS import *
from OCC.Core.StepShape import *
from OCC.Core.TopTools import *
from OCC.Core.XSControl import *
from OCC.Core.Interface import *
from OCC.Core.IFSelect import *
from OCC.Core.TColStd import *
from OCC.Core.StepData import *


class STEPControl_StepModelType(IntEnum):
	STEPControl_AsIs: int = ...
	STEPControl_ManifoldSolidBrep: int = ...
	STEPControl_BrepWithVoids: int = ...
	STEPControl_FacetedBrep: int = ...
	STEPControl_FacetedBrepAndBrepWithVoids: int = ...
	STEPControl_ShellBasedSurfaceModel: int = ...
	STEPControl_GeometricCurveSet: int = ...
	STEPControl_Hybrid: int = ...
STEPControl_AsIs = STEPControl_StepModelType.STEPControl_AsIs
STEPControl_ManifoldSolidBrep = STEPControl_StepModelType.STEPControl_ManifoldSolidBrep
STEPControl_BrepWithVoids = STEPControl_StepModelType.STEPControl_BrepWithVoids
STEPControl_FacetedBrep = STEPControl_StepModelType.STEPControl_FacetedBrep
STEPControl_FacetedBrepAndBrepWithVoids = STEPControl_StepModelType.STEPControl_FacetedBrepAndBrepWithVoids
STEPControl_ShellBasedSurfaceModel = STEPControl_StepModelType.STEPControl_ShellBasedSurfaceModel
STEPControl_GeometricCurveSet = STEPControl_StepModelType.STEPControl_GeometricCurveSet
STEPControl_Hybrid = STEPControl_StepModelType.STEPControl_Hybrid

class STEPControl_ActorRead(Transfer_ActorOfTransientProcess):
	def __init__(self) -> None: ...
	def ComputeSRRWT(self, SRR: StepRepr_RepresentationRelationship, TP: Transfer_TransientProcess, Trsf: gp_Trsf) -> bool: ...
	def ComputeTransformation(self, Origin: StepGeom_Axis2Placement3d, Target: StepGeom_Axis2Placement3d, OrigContext: StepRepr_Representation, TargContext: StepRepr_Representation, TP: Transfer_TransientProcess, Trsf: gp_Trsf) -> bool: ...
	def PrepareUnits(self, rep: StepRepr_Representation, TP: Transfer_TransientProcess) -> None: ...
	def Recognize(self, start: Standard_Transient) -> bool: ...
	def ResetUnits(self) -> None: ...
	def Transfer(self, start: Standard_Transient, TP: Transfer_TransientProcess, theProgress: Optional[Message_ProgressRange] = Message_ProgressRange()) -> Transfer_Binder: ...
	def TransferShape(self, start: Standard_Transient, TP: Transfer_TransientProcess, isManifold: Optional[bool] = True, theUseTrsf: Optional[bool] = False, theProgress: Optional[Message_ProgressRange] = Message_ProgressRange()) -> Transfer_Binder: ...

class STEPControl_ActorWrite(Transfer_ActorOfFinderProcess):
	def __init__(self) -> None: ...
	def GroupMode(self) -> int: ...
	def IsAssembly(self, S: TopoDS_Shape) -> bool: ...
	def Mode(self) -> STEPControl_StepModelType: ...
	def Recognize(self, start: Transfer_Finder) -> bool: ...
	def SetGroupMode(self, mode: int) -> None: ...
	def SetMode(self, M: STEPControl_StepModelType) -> None: ...
	def SetTolerance(self, Tol: float) -> None: ...
	def Transfer(self, start: Transfer_Finder, FP: Transfer_FinderProcess, theProgress: Optional[Message_ProgressRange] = Message_ProgressRange()) -> Transfer_Binder: ...
	def TransferCompound(self, start: Transfer_Finder, SDR: StepShape_ShapeDefinitionRepresentation, FP: Transfer_FinderProcess, theProgress: Optional[Message_ProgressRange] = Message_ProgressRange()) -> Transfer_Binder: ...
	def TransferShape(self, start: Transfer_Finder, SDR: StepShape_ShapeDefinitionRepresentation, FP: Transfer_FinderProcess, shapeGroup: Optional[TopTools_HSequenceOfShape] = None, isManifold: Optional[bool] = True, theProgress: Optional[Message_ProgressRange] = Message_ProgressRange()) -> Transfer_Binder: ...
	def TransferSubShape(self, start: Transfer_Finder, SDR: StepShape_ShapeDefinitionRepresentation, AX1: StepGeom_Axis2Placement3d, FP: Transfer_FinderProcess, shapeGroup: Optional[TopTools_HSequenceOfShape] = None, isManifold: Optional[bool] = True, theProgress: Optional[Message_ProgressRange] = Message_ProgressRange()) -> Transfer_Binder: ...

class STEPControl_Controller(XSControl_Controller):
	def __init__(self) -> None: ...
	def Customise(self, WS: XSControl_WorkSession) -> None: ...
	@staticmethod
	def Init() -> bool: ...
	def NewModel(self) -> Interface_InterfaceModel: ...
	def TransferWriteShape(self, shape: TopoDS_Shape, FP: Transfer_FinderProcess, model: Interface_InterfaceModel, modetrans: Optional[int] = 0, theProgress: Optional[Message_ProgressRange] = Message_ProgressRange()) -> IFSelect_ReturnStatus: ...

class STEPControl_Reader(XSControl_Reader):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, WS: XSControl_WorkSession, scratch: Optional[bool] = True) -> None: ...
	def FileUnits(self, theUnitLengthNames: TColStd_SequenceOfAsciiString, theUnitAngleNames: TColStd_SequenceOfAsciiString, theUnitSolidAngleNames: TColStd_SequenceOfAsciiString) -> None: ...
	def NbRootsForTransfer(self) -> int: ...
	def StepModel(self) -> StepData_StepModel: ...
	def TransferRoot(self, num: Optional[int] = 1, theProgress: Optional[Message_ProgressRange] = Message_ProgressRange()) -> bool: ...

class STEPControl_Writer:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, WS: XSControl_WorkSession, scratch: Optional[bool] = True) -> None: ...
	def Model(self, newone: Optional[bool] = False) -> StepData_StepModel: ...
	def PrintStatsTransfer(self, what: int, mode: Optional[int] = 0) -> None: ...
	def SetTolerance(self, Tol: float) -> None: ...
	def SetWS(self, WS: XSControl_WorkSession, scratch: Optional[bool] = True) -> None: ...
	def Transfer(self, sh: TopoDS_Shape, mode: STEPControl_StepModelType, compgraph: Optional[bool] = True, theProgress: Optional[Message_ProgressRange] = Message_ProgressRange()) -> IFSelect_ReturnStatus: ...
	def UnsetTolerance(self) -> None: ...
	def WS(self) -> XSControl_WorkSession: ...
	def Write(self, filename: str) -> IFSelect_ReturnStatus: ...

# harray1 classes
# harray2 classes
# hsequence classes

STEPControl_Controller_Init = STEPControl_Controller.Init



from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.MAT import *
from OCC.Core.GeomAbs import *
from OCC.Core.Bisector import *
from OCC.Core.Geom2d import *
from OCC.Core.gp import *
from OCC.Core.TopoDS import *
from OCC.Core.TColGeom2d import *
from OCC.Core.TColStd import *


class BRepMAT2d_BisectingLocus:
	def __init__(self) -> None: ...
	def BasicElt(self, IndLine: int, Index: int) -> MAT_BasicElt: ...
	def Compute(self, anExplo: BRepMAT2d_Explorer, LineIndex: Optional[int] = 1, aSide: Optional[MAT_Side] = MAT_Left, aJoinType: Optional[GeomAbs_JoinType] = GeomAbs_Arc, IsOpenResult: Optional[bool] = False) -> None: ...
	def GeomBis(self, anArc: MAT_Arc) -> Tuple[Bisector_Bisec, bool]: ...
	@overload
	def GeomElt(self, aBasicElt: MAT_BasicElt) -> Geom2d_Geometry: ...
	@overload
	def GeomElt(self, aNode: MAT_Node) -> gp_Pnt2d: ...
	def Graph(self) -> MAT_Graph: ...
	def IsDone(self) -> bool: ...
	def NumberOfContours(self) -> int: ...
	def NumberOfElts(self, IndLine: int) -> int: ...
	def NumberOfSections(self, IndLine: int, Index: int) -> int: ...

class BRepMAT2d_Explorer:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, aFace: TopoDS_Face) -> None: ...
	def Clear(self) -> None: ...
	def Contour(self, IndexContour: int) -> TColGeom2d_SequenceOfCurve: ...
	def GetIsClosed(self) -> TColStd_SequenceOfBoolean: ...
	def Init(self, IndexContour: int) -> None: ...
	def IsModified(self, aShape: TopoDS_Shape) -> bool: ...
	def ModifiedShape(self, aShape: TopoDS_Shape) -> TopoDS_Shape: ...
	def More(self) -> bool: ...
	def Next(self) -> None: ...
	def NumberOfContours(self) -> int: ...
	def NumberOfCurves(self, IndexContour: int) -> int: ...
	def Perform(self, aFace: TopoDS_Face) -> None: ...
	def Shape(self) -> TopoDS_Shape: ...
	def Value(self) -> Geom2d_Curve: ...

class BRepMAT2d_LinkTopoBilo:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, Explo: BRepMAT2d_Explorer, BiLo: BRepMAT2d_BisectingLocus) -> None: ...
	def GeneratingShape(self, aBE: MAT_BasicElt) -> TopoDS_Shape: ...
	def Init(self, S: TopoDS_Shape) -> None: ...
	def More(self) -> bool: ...
	def Next(self) -> None: ...
	def Perform(self, Explo: BRepMAT2d_Explorer, BiLo: BRepMAT2d_BisectingLocus) -> None: ...
	def Value(self) -> MAT_BasicElt: ...

# harray1 classes
# harray2 classes
# hsequence classes




from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.gp import *
from OCC.Core.GeomAbs import *
from OCC.Core.TColgp import *
from OCC.Core.TColStd import *


class Geom_SequenceOfBSplineSurface:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Length(self) -> int: ...
    def Append(self, theItem: False) -> False: ...
    def Prepend(self, theItem: False) -> False: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class Geom_Geometry(Standard_Transient):
	def Copy(self) -> Geom_Geometry: ...
	@overload
	def Mirror(self, P: gp_Pnt) -> None: ...
	@overload
	def Mirror(self, A1: gp_Ax1) -> None: ...
	@overload
	def Mirror(self, A2: gp_Ax2) -> None: ...
	@overload
	def Mirrored(self, P: gp_Pnt) -> Geom_Geometry: ...
	@overload
	def Mirrored(self, A1: gp_Ax1) -> Geom_Geometry: ...
	@overload
	def Mirrored(self, A2: gp_Ax2) -> Geom_Geometry: ...
	def Rotate(self, A1: gp_Ax1, Ang: float) -> None: ...
	def Rotated(self, A1: gp_Ax1, Ang: float) -> Geom_Geometry: ...
	def Scale(self, P: gp_Pnt, S: float) -> None: ...
	def Scaled(self, P: gp_Pnt, S: float) -> Geom_Geometry: ...
	def Transform(self, T: gp_Trsf) -> None: ...
	def Transformed(self, T: gp_Trsf) -> Geom_Geometry: ...
	@overload
	def Translate(self, V: gp_Vec) -> None: ...
	@overload
	def Translate(self, P1: gp_Pnt, P2: gp_Pnt) -> None: ...
	@overload
	def Translated(self, V: gp_Vec) -> Geom_Geometry: ...
	@overload
	def Translated(self, P1: gp_Pnt, P2: gp_Pnt) -> Geom_Geometry: ...

class Geom_OsculatingSurface(Standard_Transient):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, BS: Geom_Surface, Tol: float) -> None: ...
	def BasisSurface(self) -> Geom_Surface: ...
	def Init(self, BS: Geom_Surface, Tol: float) -> None: ...
	def Tolerance(self) -> float: ...
	def UOscSurf(self, U: float, V: float, L: Geom_BSplineSurface) -> Tuple[bool, bool]: ...
	def VOscSurf(self, U: float, V: float, L: Geom_BSplineSurface) -> Tuple[bool, bool]: ...

class Geom_Transformation(Standard_Transient):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, T: gp_Trsf) -> None: ...
	def Copy(self) -> Geom_Transformation: ...
	def Form(self) -> gp_TrsfForm: ...
	def Invert(self) -> None: ...
	def Inverted(self) -> Geom_Transformation: ...
	def IsNegative(self) -> bool: ...
	def Multiplied(self, Other: Geom_Transformation) -> Geom_Transformation: ...
	def Multiply(self, theOther: Geom_Transformation) -> None: ...
	def Power(self, N: int) -> None: ...
	def Powered(self, N: int) -> Geom_Transformation: ...
	def PreMultiply(self, Other: Geom_Transformation) -> None: ...
	def ScaleFactor(self) -> float: ...
	@overload
	def SetMirror(self, thePnt: gp_Pnt) -> None: ...
	@overload
	def SetMirror(self, theA1: gp_Ax1) -> None: ...
	@overload
	def SetMirror(self, theA2: gp_Ax2) -> None: ...
	def SetRotation(self, theA1: gp_Ax1, theAng: float) -> None: ...
	def SetScale(self, thePnt: gp_Pnt, theScale: float) -> None: ...
	@overload
	def SetTransformation(self, theFromSystem1: gp_Ax3, theToSystem2: gp_Ax3) -> None: ...
	@overload
	def SetTransformation(self, theToSystem: gp_Ax3) -> None: ...
	@overload
	def SetTranslation(self, theVec: gp_Vec) -> None: ...
	@overload
	def SetTranslation(self, P1: gp_Pnt, P2: gp_Pnt) -> None: ...
	def SetTrsf(self, theTrsf: gp_Trsf) -> None: ...
	def Transforms(self) -> Tuple[float, float, float]: ...
	def Trsf(self) -> gp_Trsf: ...
	def Value(self, theRow: int, theCol: int) -> float: ...

class Geom_AxisPlacement(Geom_Geometry):
	def Angle(self, Other: Geom_AxisPlacement) -> float: ...
	def Axis(self) -> gp_Ax1: ...
	def Direction(self) -> gp_Dir: ...
	def Location(self) -> gp_Pnt: ...
	def SetAxis(self, A1: gp_Ax1) -> None: ...
	def SetDirection(self, V: gp_Dir) -> None: ...
	def SetLocation(self, P: gp_Pnt) -> None: ...

class Geom_Curve(Geom_Geometry):
	def Continuity(self) -> GeomAbs_Shape: ...
	def D0(self, U: float, P: gp_Pnt) -> None: ...
	def D1(self, U: float, P: gp_Pnt, V1: gp_Vec) -> None: ...
	def D2(self, U: float, P: gp_Pnt, V1: gp_Vec, V2: gp_Vec) -> None: ...
	def D3(self, U: float, P: gp_Pnt, V1: gp_Vec, V2: gp_Vec, V3: gp_Vec) -> None: ...
	def DN(self, U: float, N: int) -> gp_Vec: ...
	def FirstParameter(self) -> float: ...
	def IsCN(self, N: int) -> bool: ...
	def IsClosed(self) -> bool: ...
	def IsPeriodic(self) -> bool: ...
	def LastParameter(self) -> float: ...
	def ParametricTransformation(self, T: gp_Trsf) -> float: ...
	def Period(self) -> float: ...
	def Reverse(self) -> None: ...
	def Reversed(self) -> Geom_Curve: ...
	def ReversedParameter(self, U: float) -> float: ...
	def TransformedParameter(self, U: float, T: gp_Trsf) -> float: ...
	def Value(self, U: float) -> gp_Pnt: ...

class Geom_Point(Geom_Geometry):
	def Coord(self) -> Tuple[float, float, float]: ...
	def Distance(self, Other: Geom_Point) -> float: ...
	def Pnt(self) -> gp_Pnt: ...
	def SquareDistance(self, Other: Geom_Point) -> float: ...
	def X(self) -> float: ...
	def Y(self) -> float: ...
	def Z(self) -> float: ...

class Geom_Surface(Geom_Geometry):
	def Bounds(self) -> Tuple[float, float, float, float]: ...
	def Continuity(self) -> GeomAbs_Shape: ...
	def D0(self, U: float, V: float, P: gp_Pnt) -> None: ...
	def D1(self, U: float, V: float, P: gp_Pnt, D1U: gp_Vec, D1V: gp_Vec) -> None: ...
	def D2(self, U: float, V: float, P: gp_Pnt, D1U: gp_Vec, D1V: gp_Vec, D2U: gp_Vec, D2V: gp_Vec, D2UV: gp_Vec) -> None: ...
	def D3(self, U: float, V: float, P: gp_Pnt, D1U: gp_Vec, D1V: gp_Vec, D2U: gp_Vec, D2V: gp_Vec, D2UV: gp_Vec, D3U: gp_Vec, D3V: gp_Vec, D3UUV: gp_Vec, D3UVV: gp_Vec) -> None: ...
	def DN(self, U: float, V: float, Nu: int, Nv: int) -> gp_Vec: ...
	def IsCNu(self, N: int) -> bool: ...
	def IsCNv(self, N: int) -> bool: ...
	def IsUClosed(self) -> bool: ...
	def IsUPeriodic(self) -> bool: ...
	def IsVClosed(self) -> bool: ...
	def IsVPeriodic(self) -> bool: ...
	def ParametricTransformation(self, T: gp_Trsf) -> gp_GTrsf2d: ...
	def TransformParameters(self, T: gp_Trsf) -> Tuple[float, float]: ...
	def UIso(self, U: float) -> Geom_Curve: ...
	def UPeriod(self) -> float: ...
	def UReverse(self) -> None: ...
	def UReversed(self) -> Geom_Surface: ...
	def UReversedParameter(self, U: float) -> float: ...
	def VIso(self, V: float) -> Geom_Curve: ...
	def VPeriod(self) -> float: ...
	def VReverse(self) -> None: ...
	def VReversed(self) -> Geom_Surface: ...
	def VReversedParameter(self, V: float) -> float: ...
	def Value(self, U: float, V: float) -> gp_Pnt: ...

class Geom_Vector(Geom_Geometry):
	def Angle(self, Other: Geom_Vector) -> float: ...
	def AngleWithRef(self, Other: Geom_Vector, VRef: Geom_Vector) -> float: ...
	def Coord(self) -> Tuple[float, float, float]: ...
	def Cross(self, Other: Geom_Vector) -> None: ...
	def CrossCross(self, V1: Geom_Vector, V2: Geom_Vector) -> None: ...
	def CrossCrossed(self, V1: Geom_Vector, V2: Geom_Vector) -> Geom_Vector: ...
	def Crossed(self, Other: Geom_Vector) -> Geom_Vector: ...
	def Dot(self, Other: Geom_Vector) -> float: ...
	def DotCross(self, V1: Geom_Vector, V2: Geom_Vector) -> float: ...
	def Magnitude(self) -> float: ...
	def Reverse(self) -> None: ...
	def Reversed(self) -> Geom_Vector: ...
	def SquareMagnitude(self) -> float: ...
	def Vec(self) -> gp_Vec: ...
	def X(self) -> float: ...
	def Y(self) -> float: ...
	def Z(self) -> float: ...

class Geom_Axis1Placement(Geom_AxisPlacement):
	@overload
	def __init__(self, A1: gp_Ax1) -> None: ...
	@overload
	def __init__(self, P: gp_Pnt, V: gp_Dir) -> None: ...
	def Ax1(self) -> gp_Ax1: ...
	def Copy(self) -> Geom_Geometry: ...
	def Reverse(self) -> None: ...
	def Reversed(self) -> Geom_Axis1Placement: ...
	def SetDirection(self, V: gp_Dir) -> None: ...
	def Transform(self, T: gp_Trsf) -> None: ...

class Geom_Axis2Placement(Geom_AxisPlacement):
	@overload
	def __init__(self, A2: gp_Ax2) -> None: ...
	@overload
	def __init__(self, P: gp_Pnt, N: gp_Dir, Vx: gp_Dir) -> None: ...
	def Ax2(self) -> gp_Ax2: ...
	def Copy(self) -> Geom_Geometry: ...
	def SetAx2(self, A2: gp_Ax2) -> None: ...
	def SetDirection(self, V: gp_Dir) -> None: ...
	def SetXDirection(self, Vx: gp_Dir) -> None: ...
	def SetYDirection(self, Vy: gp_Dir) -> None: ...
	def Transform(self, T: gp_Trsf) -> None: ...
	def XDirection(self) -> gp_Dir: ...
	def YDirection(self) -> gp_Dir: ...

class Geom_BoundedCurve(Geom_Curve):
	def EndPoint(self) -> gp_Pnt: ...
	def StartPoint(self) -> gp_Pnt: ...

class Geom_BoundedSurface(Geom_Surface):
	pass

class Geom_CartesianPoint(Geom_Point):
	@overload
	def __init__(self, P: gp_Pnt) -> None: ...
	@overload
	def __init__(self, X: float, Y: float, Z: float) -> None: ...
	def Coord(self) -> Tuple[float, float, float]: ...
	def Copy(self) -> Geom_Geometry: ...
	def Pnt(self) -> gp_Pnt: ...
	def SetCoord(self, X: float, Y: float, Z: float) -> None: ...
	def SetPnt(self, P: gp_Pnt) -> None: ...
	def SetX(self, X: float) -> None: ...
	def SetY(self, Y: float) -> None: ...
	def SetZ(self, Z: float) -> None: ...
	def Transform(self, T: gp_Trsf) -> None: ...
	def X(self) -> float: ...
	def Y(self) -> float: ...
	def Z(self) -> float: ...

class Geom_Conic(Geom_Curve):
	def Axis(self) -> gp_Ax1: ...
	def Continuity(self) -> GeomAbs_Shape: ...
	def Eccentricity(self) -> float: ...
	def IsCN(self, N: int) -> bool: ...
	def Location(self) -> gp_Pnt: ...
	def Position(self) -> gp_Ax2: ...
	def Reverse(self) -> None: ...
	def ReversedParameter(self, U: float) -> float: ...
	def SetAxis(self, theA1: gp_Ax1) -> None: ...
	def SetLocation(self, theP: gp_Pnt) -> None: ...
	def SetPosition(self, theA2: gp_Ax2) -> None: ...
	def XAxis(self) -> gp_Ax1: ...
	def YAxis(self) -> gp_Ax1: ...

class Geom_Direction(Geom_Vector):
	@overload
	def __init__(self, X: float, Y: float, Z: float) -> None: ...
	@overload
	def __init__(self, V: gp_Dir) -> None: ...
	def Copy(self) -> Geom_Geometry: ...
	def Cross(self, Other: Geom_Vector) -> None: ...
	def CrossCross(self, V1: Geom_Vector, V2: Geom_Vector) -> None: ...
	def CrossCrossed(self, V1: Geom_Vector, V2: Geom_Vector) -> Geom_Vector: ...
	def Crossed(self, Other: Geom_Vector) -> Geom_Vector: ...
	def Dir(self) -> gp_Dir: ...
	def Magnitude(self) -> float: ...
	def SetCoord(self, X: float, Y: float, Z: float) -> None: ...
	def SetDir(self, V: gp_Dir) -> None: ...
	def SetX(self, X: float) -> None: ...
	def SetY(self, Y: float) -> None: ...
	def SetZ(self, Z: float) -> None: ...
	def SquareMagnitude(self) -> float: ...
	def Transform(self, T: gp_Trsf) -> None: ...

class Geom_ElementarySurface(Geom_Surface):
	def Axis(self) -> gp_Ax1: ...
	def Continuity(self) -> GeomAbs_Shape: ...
	def IsCNu(self, N: int) -> bool: ...
	def IsCNv(self, N: int) -> bool: ...
	def Location(self) -> gp_Pnt: ...
	def Position(self) -> gp_Ax3: ...
	def SetAxis(self, theA1: gp_Ax1) -> None: ...
	def SetLocation(self, theLoc: gp_Pnt) -> None: ...
	def SetPosition(self, theAx3: gp_Ax3) -> None: ...
	def UReverse(self) -> None: ...
	def UReversedParameter(self, U: float) -> float: ...
	def VReverse(self) -> None: ...
	def VReversedParameter(self, V: float) -> float: ...

class Geom_Line(Geom_Curve):
	@overload
	def __init__(self, A1: gp_Ax1) -> None: ...
	@overload
	def __init__(self, L: gp_Lin) -> None: ...
	@overload
	def __init__(self, P: gp_Pnt, V: gp_Dir) -> None: ...
	def Continuity(self) -> GeomAbs_Shape: ...
	def Copy(self) -> Geom_Geometry: ...
	def D0(self, U: float, P: gp_Pnt) -> None: ...
	def D1(self, U: float, P: gp_Pnt, V1: gp_Vec) -> None: ...
	def D2(self, U: float, P: gp_Pnt, V1: gp_Vec, V2: gp_Vec) -> None: ...
	def D3(self, U: float, P: gp_Pnt, V1: gp_Vec, V2: gp_Vec, V3: gp_Vec) -> None: ...
	def DN(self, U: float, N: int) -> gp_Vec: ...
	def FirstParameter(self) -> float: ...
	def IsCN(self, N: int) -> bool: ...
	def IsClosed(self) -> bool: ...
	def IsPeriodic(self) -> bool: ...
	def LastParameter(self) -> float: ...
	def Lin(self) -> gp_Lin: ...
	def ParametricTransformation(self, T: gp_Trsf) -> float: ...
	def Position(self) -> gp_Ax1: ...
	def Reverse(self) -> None: ...
	def ReversedParameter(self, U: float) -> float: ...
	def SetDirection(self, V: gp_Dir) -> None: ...
	def SetLin(self, L: gp_Lin) -> None: ...
	def SetLocation(self, P: gp_Pnt) -> None: ...
	def SetPosition(self, A1: gp_Ax1) -> None: ...
	def Transform(self, T: gp_Trsf) -> None: ...
	def TransformedParameter(self, U: float, T: gp_Trsf) -> float: ...

class Geom_OffsetCurve(Geom_Curve):
	def __init__(self, C: Geom_Curve, Offset: float, V: gp_Dir, isNotCheckC0: Optional[bool] = False) -> None: ...
	def BasisCurve(self) -> Geom_Curve: ...
	def Continuity(self) -> GeomAbs_Shape: ...
	def Copy(self) -> Geom_Geometry: ...
	def D0(self, U: float, P: gp_Pnt) -> None: ...
	def D1(self, U: float, P: gp_Pnt, V1: gp_Vec) -> None: ...
	def D2(self, U: float, P: gp_Pnt, V1: gp_Vec, V2: gp_Vec) -> None: ...
	def D3(self, U: float, P: gp_Pnt, V1: gp_Vec, V2: gp_Vec, V3: gp_Vec) -> None: ...
	def DN(self, U: float, N: int) -> gp_Vec: ...
	def Direction(self) -> gp_Dir: ...
	def FirstParameter(self) -> float: ...
	def GetBasisCurveContinuity(self) -> GeomAbs_Shape: ...
	def IsCN(self, N: int) -> bool: ...
	def IsClosed(self) -> bool: ...
	def IsPeriodic(self) -> bool: ...
	def LastParameter(self) -> float: ...
	def Offset(self) -> float: ...
	def ParametricTransformation(self, T: gp_Trsf) -> float: ...
	def Period(self) -> float: ...
	def Reverse(self) -> None: ...
	def ReversedParameter(self, U: float) -> float: ...
	def SetBasisCurve(self, C: Geom_Curve, isNotCheckC0: Optional[bool] = False) -> None: ...
	def SetDirection(self, V: gp_Dir) -> None: ...
	def SetOffsetValue(self, D: float) -> None: ...
	def Transform(self, T: gp_Trsf) -> None: ...
	def TransformedParameter(self, U: float, T: gp_Trsf) -> float: ...

class Geom_OffsetSurface(Geom_Surface):
	def __init__(self, S: Geom_Surface, Offset: float, isNotCheckC0: Optional[bool] = False) -> None: ...
	def BasisSurface(self) -> Geom_Surface: ...
	def Bounds(self) -> Tuple[float, float, float, float]: ...
	def Continuity(self) -> GeomAbs_Shape: ...
	def Copy(self) -> Geom_Geometry: ...
	def D0(self, U: float, V: float, P: gp_Pnt) -> None: ...
	def D1(self, U: float, V: float, P: gp_Pnt, D1U: gp_Vec, D1V: gp_Vec) -> None: ...
	def D2(self, U: float, V: float, P: gp_Pnt, D1U: gp_Vec, D1V: gp_Vec, D2U: gp_Vec, D2V: gp_Vec, D2UV: gp_Vec) -> None: ...
	def D3(self, U: float, V: float, P: gp_Pnt, D1U: gp_Vec, D1V: gp_Vec, D2U: gp_Vec, D2V: gp_Vec, D2UV: gp_Vec, D3U: gp_Vec, D3V: gp_Vec, D3UUV: gp_Vec, D3UVV: gp_Vec) -> None: ...
	def DN(self, U: float, V: float, Nu: int, Nv: int) -> gp_Vec: ...
	def GetBasisSurfContinuity(self) -> GeomAbs_Shape: ...
	def IsCNu(self, N: int) -> bool: ...
	def IsCNv(self, N: int) -> bool: ...
	def IsUClosed(self) -> bool: ...
	def IsUPeriodic(self) -> bool: ...
	def IsVClosed(self) -> bool: ...
	def IsVPeriodic(self) -> bool: ...
	def Offset(self) -> float: ...
	def OsculatingSurface(self) -> Geom_OsculatingSurface: ...
	def ParametricTransformation(self, T: gp_Trsf) -> gp_GTrsf2d: ...
	def SetBasisSurface(self, S: Geom_Surface, isNotCheckC0: Optional[bool] = False) -> None: ...
	def SetOffsetValue(self, D: float) -> None: ...
	def Surface(self) -> Geom_Surface: ...
	def Transform(self, T: gp_Trsf) -> None: ...
	def TransformParameters(self, T: gp_Trsf) -> Tuple[float, float]: ...
	def UIso(self, U: float) -> Geom_Curve: ...
	def UOsculatingSurface(self, U: float, V: float, UOsculSurf: Geom_BSplineSurface) -> Tuple[bool, bool]: ...
	def UPeriod(self) -> float: ...
	def UReverse(self) -> None: ...
	def UReversedParameter(self, U: float) -> float: ...
	def VIso(self, V: float) -> Geom_Curve: ...
	def VOsculatingSurface(self, U: float, V: float, VOsculSurf: Geom_BSplineSurface) -> Tuple[bool, bool]: ...
	def VPeriod(self) -> float: ...
	def VReverse(self) -> None: ...
	def VReversedParameter(self, V: float) -> float: ...

class Geom_SweptSurface(Geom_Surface):
	def BasisCurve(self) -> Geom_Curve: ...
	def Continuity(self) -> GeomAbs_Shape: ...
	def Direction(self) -> gp_Dir: ...

class Geom_VectorWithMagnitude(Geom_Vector):
	@overload
	def __init__(self, V: gp_Vec) -> None: ...
	@overload
	def __init__(self, X: float, Y: float, Z: float) -> None: ...
	@overload
	def __init__(self, P1: gp_Pnt, P2: gp_Pnt) -> None: ...
	def Add(self, Other: Geom_Vector) -> None: ...
	def Added(self, Other: Geom_Vector) -> Geom_VectorWithMagnitude: ...
	def Copy(self) -> Geom_Geometry: ...
	def Cross(self, Other: Geom_Vector) -> None: ...
	def CrossCross(self, V1: Geom_Vector, V2: Geom_Vector) -> None: ...
	def CrossCrossed(self, V1: Geom_Vector, V2: Geom_Vector) -> Geom_Vector: ...
	def Crossed(self, Other: Geom_Vector) -> Geom_Vector: ...
	def Divide(self, Scalar: float) -> None: ...
	def Divided(self, Scalar: float) -> Geom_VectorWithMagnitude: ...
	def Magnitude(self) -> float: ...
	def Multiplied(self, Scalar: float) -> Geom_VectorWithMagnitude: ...
	def Multiply(self, Scalar: float) -> None: ...
	def Normalize(self) -> None: ...
	def Normalized(self) -> Geom_VectorWithMagnitude: ...
	def SetCoord(self, X: float, Y: float, Z: float) -> None: ...
	def SetVec(self, V: gp_Vec) -> None: ...
	def SetX(self, X: float) -> None: ...
	def SetY(self, Y: float) -> None: ...
	def SetZ(self, Z: float) -> None: ...
	def SquareMagnitude(self) -> float: ...
	def Subtract(self, Other: Geom_Vector) -> None: ...
	def Subtracted(self, Other: Geom_Vector) -> Geom_VectorWithMagnitude: ...
	def Transform(self, T: gp_Trsf) -> None: ...

class Geom_BSplineCurve(Geom_BoundedCurve):
	@overload
	def __init__(self, Poles: TColgp_Array1OfPnt, Knots: TColStd_Array1OfReal, Multiplicities: TColStd_Array1OfInteger, Degree: int, Periodic: Optional[bool] = False) -> None: ...
	@overload
	def __init__(self, Poles: TColgp_Array1OfPnt, Weights: TColStd_Array1OfReal, Knots: TColStd_Array1OfReal, Multiplicities: TColStd_Array1OfInteger, Degree: int, Periodic: Optional[bool] = False, CheckRational: Optional[bool] = True) -> None: ...
	def Continuity(self) -> GeomAbs_Shape: ...
	def Copy(self) -> Geom_Geometry: ...
	def D0(self, U: float, P: gp_Pnt) -> None: ...
	def D1(self, U: float, P: gp_Pnt, V1: gp_Vec) -> None: ...
	def D2(self, U: float, P: gp_Pnt, V1: gp_Vec, V2: gp_Vec) -> None: ...
	def D3(self, U: float, P: gp_Pnt, V1: gp_Vec, V2: gp_Vec, V3: gp_Vec) -> None: ...
	def DN(self, U: float, N: int) -> gp_Vec: ...
	def Degree(self) -> int: ...
	def EndPoint(self) -> gp_Pnt: ...
	def FirstParameter(self) -> float: ...
	def FirstUKnotIndex(self) -> int: ...
	def IncreaseDegree(self, Degree: int) -> None: ...
	@overload
	def IncreaseMultiplicity(self, Index: int, M: int) -> None: ...
	@overload
	def IncreaseMultiplicity(self, I1: int, I2: int, M: int) -> None: ...
	def IncrementMultiplicity(self, I1: int, I2: int, M: int) -> None: ...
	def InsertKnot(self, U: float, M: Optional[int] = 1, ParametricTolerance: Optional[float] = 0.0, Add: Optional[bool] = True) -> None: ...
	def InsertKnots(self, Knots: TColStd_Array1OfReal, Mults: TColStd_Array1OfInteger, ParametricTolerance: Optional[float] = 0.0, Add: Optional[bool] = False) -> None: ...
	def IsCN(self, N: int) -> bool: ...
	def IsClosed(self) -> bool: ...
	def IsEqual(self, theOther: Geom_BSplineCurve, thePreci: float) -> bool: ...
	def IsG1(self, theTf: float, theTl: float, theAngTol: float) -> bool: ...
	def IsPeriodic(self) -> bool: ...
	def IsRational(self) -> bool: ...
	def Knot(self, Index: int) -> float: ...
	def KnotDistribution(self) -> GeomAbs_BSplKnotDistribution: ...
	@overload
	def KnotSequence(self, K: TColStd_Array1OfReal) -> None: ...
	@overload
	def KnotSequence(self) -> TColStd_Array1OfReal: ...
	@overload
	def Knots(self, K: TColStd_Array1OfReal) -> None: ...
	@overload
	def Knots(self) -> TColStd_Array1OfReal: ...
	def LastParameter(self) -> float: ...
	def LastUKnotIndex(self) -> int: ...
	def LocalD0(self, U: float, FromK1: int, ToK2: int, P: gp_Pnt) -> None: ...
	def LocalD1(self, U: float, FromK1: int, ToK2: int, P: gp_Pnt, V1: gp_Vec) -> None: ...
	def LocalD2(self, U: float, FromK1: int, ToK2: int, P: gp_Pnt, V1: gp_Vec, V2: gp_Vec) -> None: ...
	def LocalD3(self, U: float, FromK1: int, ToK2: int, P: gp_Pnt, V1: gp_Vec, V2: gp_Vec, V3: gp_Vec) -> None: ...
	def LocalDN(self, U: float, FromK1: int, ToK2: int, N: int) -> gp_Vec: ...
	def LocalValue(self, U: float, FromK1: int, ToK2: int) -> gp_Pnt: ...
	def LocateU(self, U: float, ParametricTolerance: float, WithKnotRepetition: Optional[bool] = False) -> Tuple[int, int]: ...
	@staticmethod
	def MaxDegree() -> int: ...
	def MovePoint(self, U: float, P: gp_Pnt, Index1: int, Index2: int) -> Tuple[int, int]: ...
	def MovePointAndTangent(self, U: float, P: gp_Pnt, Tangent: gp_Vec, Tolerance: float, StartingCondition: int, EndingCondition: int) -> int: ...
	@overload
	def Multiplicities(self, M: TColStd_Array1OfInteger) -> None: ...
	@overload
	def Multiplicities(self) -> TColStd_Array1OfInteger: ...
	def Multiplicity(self, Index: int) -> int: ...
	def NbKnots(self) -> int: ...
	def NbPoles(self) -> int: ...
	def PeriodicNormalization(self) -> float: ...
	def Pole(self, Index: int) -> gp_Pnt: ...
	@overload
	def Poles(self, P: TColgp_Array1OfPnt) -> None: ...
	@overload
	def Poles(self) -> TColgp_Array1OfPnt: ...
	def RemoveKnot(self, Index: int, M: int, Tolerance: float) -> bool: ...
	def Resolution(self, Tolerance3D: float) -> float: ...
	def Reverse(self) -> None: ...
	def ReversedParameter(self, U: float) -> float: ...
	def Segment(self, U1: float, U2: float, theTolerance: Optional[float] = precision_PConfusion()) -> None: ...
	@overload
	def SetKnot(self, Index: int, K: float) -> None: ...
	@overload
	def SetKnot(self, Index: int, K: float, M: int) -> None: ...
	def SetKnots(self, K: TColStd_Array1OfReal) -> None: ...
	def SetNotPeriodic(self) -> None: ...
	@overload
	def SetOrigin(self, Index: int) -> None: ...
	@overload
	def SetOrigin(self, U: float, Tol: float) -> None: ...
	def SetPeriodic(self) -> None: ...
	@overload
	def SetPole(self, Index: int, P: gp_Pnt) -> None: ...
	@overload
	def SetPole(self, Index: int, P: gp_Pnt, Weight: float) -> None: ...
	def SetWeight(self, Index: int, Weight: float) -> None: ...
	def StartPoint(self) -> gp_Pnt: ...
	def Transform(self, T: gp_Trsf) -> None: ...
	def Weight(self, Index: int) -> float: ...
	@overload
	def Weights(self, W: TColStd_Array1OfReal) -> None: ...
	@overload
	def Weights(self) -> TColStd_Array1OfReal: ...

class Geom_BSplineSurface(Geom_BoundedSurface):
	@overload
	def __init__(self, Poles: TColgp_Array2OfPnt, UKnots: TColStd_Array1OfReal, VKnots: TColStd_Array1OfReal, UMults: TColStd_Array1OfInteger, VMults: TColStd_Array1OfInteger, UDegree: int, VDegree: int, UPeriodic: Optional[bool] = False, VPeriodic: Optional[bool] = False) -> None: ...
	@overload
	def __init__(self, Poles: TColgp_Array2OfPnt, Weights: TColStd_Array2OfReal, UKnots: TColStd_Array1OfReal, VKnots: TColStd_Array1OfReal, UMults: TColStd_Array1OfInteger, VMults: TColStd_Array1OfInteger, UDegree: int, VDegree: int, UPeriodic: Optional[bool] = False, VPeriodic: Optional[bool] = False) -> None: ...
	def Bounds(self) -> Tuple[float, float, float, float]: ...
	def CheckAndSegment(self, U1: float, U2: float, V1: float, V2: float, theUTolerance: Optional[float] = precision_PConfusion(), theVTolerance: Optional[float] = precision_PConfusion()) -> None: ...
	def Continuity(self) -> GeomAbs_Shape: ...
	def Copy(self) -> Geom_Geometry: ...
	def D0(self, U: float, V: float, P: gp_Pnt) -> None: ...
	def D1(self, U: float, V: float, P: gp_Pnt, D1U: gp_Vec, D1V: gp_Vec) -> None: ...
	def D2(self, U: float, V: float, P: gp_Pnt, D1U: gp_Vec, D1V: gp_Vec, D2U: gp_Vec, D2V: gp_Vec, D2UV: gp_Vec) -> None: ...
	def D3(self, U: float, V: float, P: gp_Pnt, D1U: gp_Vec, D1V: gp_Vec, D2U: gp_Vec, D2V: gp_Vec, D2UV: gp_Vec, D3U: gp_Vec, D3V: gp_Vec, D3UUV: gp_Vec, D3UVV: gp_Vec) -> None: ...
	def DN(self, U: float, V: float, Nu: int, Nv: int) -> gp_Vec: ...
	def ExchangeUV(self) -> None: ...
	def FirstUKnotIndex(self) -> int: ...
	def FirstVKnotIndex(self) -> int: ...
	def IncreaseDegree(self, UDegree: int, VDegree: int) -> None: ...
	@overload
	def IncreaseUMultiplicity(self, UIndex: int, M: int) -> None: ...
	@overload
	def IncreaseUMultiplicity(self, FromI1: int, ToI2: int, M: int) -> None: ...
	@overload
	def IncreaseVMultiplicity(self, VIndex: int, M: int) -> None: ...
	@overload
	def IncreaseVMultiplicity(self, FromI1: int, ToI2: int, M: int) -> None: ...
	def IncrementUMultiplicity(self, FromI1: int, ToI2: int, Step: int) -> None: ...
	def IncrementVMultiplicity(self, FromI1: int, ToI2: int, Step: int) -> None: ...
	def InsertUKnot(self, U: float, M: int, ParametricTolerance: float, Add: Optional[bool] = True) -> None: ...
	def InsertUKnots(self, Knots: TColStd_Array1OfReal, Mults: TColStd_Array1OfInteger, ParametricTolerance: Optional[float] = 0.0, Add: Optional[bool] = True) -> None: ...
	def InsertVKnot(self, V: float, M: int, ParametricTolerance: float, Add: Optional[bool] = True) -> None: ...
	def InsertVKnots(self, Knots: TColStd_Array1OfReal, Mults: TColStd_Array1OfInteger, ParametricTolerance: Optional[float] = 0.0, Add: Optional[bool] = True) -> None: ...
	def IsCNu(self, N: int) -> bool: ...
	def IsCNv(self, N: int) -> bool: ...
	def IsUClosed(self) -> bool: ...
	def IsUPeriodic(self) -> bool: ...
	def IsURational(self) -> bool: ...
	def IsVClosed(self) -> bool: ...
	def IsVPeriodic(self) -> bool: ...
	def IsVRational(self) -> bool: ...
	def LastUKnotIndex(self) -> int: ...
	def LastVKnotIndex(self) -> int: ...
	def LocalD0(self, U: float, V: float, FromUK1: int, ToUK2: int, FromVK1: int, ToVK2: int, P: gp_Pnt) -> None: ...
	def LocalD1(self, U: float, V: float, FromUK1: int, ToUK2: int, FromVK1: int, ToVK2: int, P: gp_Pnt, D1U: gp_Vec, D1V: gp_Vec) -> None: ...
	def LocalD2(self, U: float, V: float, FromUK1: int, ToUK2: int, FromVK1: int, ToVK2: int, P: gp_Pnt, D1U: gp_Vec, D1V: gp_Vec, D2U: gp_Vec, D2V: gp_Vec, D2UV: gp_Vec) -> None: ...
	def LocalD3(self, U: float, V: float, FromUK1: int, ToUK2: int, FromVK1: int, ToVK2: int, P: gp_Pnt, D1U: gp_Vec, D1V: gp_Vec, D2U: gp_Vec, D2V: gp_Vec, D2UV: gp_Vec, D3U: gp_Vec, D3V: gp_Vec, D3UUV: gp_Vec, D3UVV: gp_Vec) -> None: ...
	def LocalDN(self, U: float, V: float, FromUK1: int, ToUK2: int, FromVK1: int, ToVK2: int, Nu: int, Nv: int) -> gp_Vec: ...
	def LocalValue(self, U: float, V: float, FromUK1: int, ToUK2: int, FromVK1: int, ToVK2: int) -> gp_Pnt: ...
	def LocateU(self, U: float, ParametricTolerance: float, WithKnotRepetition: Optional[bool] = False) -> Tuple[int, int]: ...
	def LocateV(self, V: float, ParametricTolerance: float, WithKnotRepetition: Optional[bool] = False) -> Tuple[int, int]: ...
	@staticmethod
	def MaxDegree() -> int: ...
	def MovePoint(self, U: float, V: float, P: gp_Pnt, UIndex1: int, UIndex2: int, VIndex1: int, VIndex2: int) -> Tuple[int, int, int, int]: ...
	def NbUKnots(self) -> int: ...
	def NbUPoles(self) -> int: ...
	def NbVKnots(self) -> int: ...
	def NbVPoles(self) -> int: ...
	def PeriodicNormalization(self) -> Tuple[float, float]: ...
	def Pole(self, UIndex: int, VIndex: int) -> gp_Pnt: ...
	@overload
	def Poles(self, P: TColgp_Array2OfPnt) -> None: ...
	@overload
	def Poles(self) -> TColgp_Array2OfPnt: ...
	def RemoveUKnot(self, Index: int, M: int, Tolerance: float) -> bool: ...
	def RemoveVKnot(self, Index: int, M: int, Tolerance: float) -> bool: ...
	def Resolution(self, Tolerance3D: float) -> Tuple[float, float]: ...
	def Segment(self, U1: float, U2: float, V1: float, V2: float, theUTolerance: Optional[float] = precision_PConfusion(), theVTolerance: Optional[float] = precision_PConfusion()) -> None: ...
	@overload
	def SetPole(self, UIndex: int, VIndex: int, P: gp_Pnt) -> None: ...
	@overload
	def SetPole(self, UIndex: int, VIndex: int, P: gp_Pnt, Weight: float) -> None: ...
	@overload
	def SetPoleCol(self, VIndex: int, CPoles: TColgp_Array1OfPnt) -> None: ...
	@overload
	def SetPoleCol(self, VIndex: int, CPoles: TColgp_Array1OfPnt, CPoleWeights: TColStd_Array1OfReal) -> None: ...
	@overload
	def SetPoleRow(self, UIndex: int, CPoles: TColgp_Array1OfPnt, CPoleWeights: TColStd_Array1OfReal) -> None: ...
	@overload
	def SetPoleRow(self, UIndex: int, CPoles: TColgp_Array1OfPnt) -> None: ...
	@overload
	def SetUKnot(self, UIndex: int, K: float) -> None: ...
	@overload
	def SetUKnot(self, UIndex: int, K: float, M: int) -> None: ...
	def SetUKnots(self, UK: TColStd_Array1OfReal) -> None: ...
	def SetUNotPeriodic(self) -> None: ...
	def SetUOrigin(self, Index: int) -> None: ...
	def SetUPeriodic(self) -> None: ...
	@overload
	def SetVKnot(self, VIndex: int, K: float) -> None: ...
	@overload
	def SetVKnot(self, VIndex: int, K: float, M: int) -> None: ...
	def SetVKnots(self, VK: TColStd_Array1OfReal) -> None: ...
	def SetVNotPeriodic(self) -> None: ...
	def SetVOrigin(self, Index: int) -> None: ...
	def SetVPeriodic(self) -> None: ...
	def SetWeight(self, UIndex: int, VIndex: int, Weight: float) -> None: ...
	def SetWeightCol(self, VIndex: int, CPoleWeights: TColStd_Array1OfReal) -> None: ...
	def SetWeightRow(self, UIndex: int, CPoleWeights: TColStd_Array1OfReal) -> None: ...
	def Transform(self, T: gp_Trsf) -> None: ...
	def UDegree(self) -> int: ...
	@overload
	def UIso(self, U: float) -> Geom_Curve: ...
	@overload
	def UIso(self, U: float, CheckRational: bool) -> Geom_Curve: ...
	def UKnot(self, UIndex: int) -> float: ...
	def UKnotDistribution(self) -> GeomAbs_BSplKnotDistribution: ...
	@overload
	def UKnotSequence(self, Ku: TColStd_Array1OfReal) -> None: ...
	@overload
	def UKnotSequence(self) -> TColStd_Array1OfReal: ...
	@overload
	def UKnots(self, Ku: TColStd_Array1OfReal) -> None: ...
	@overload
	def UKnots(self) -> TColStd_Array1OfReal: ...
	@overload
	def UMultiplicities(self, Mu: TColStd_Array1OfInteger) -> None: ...
	@overload
	def UMultiplicities(self) -> TColStd_Array1OfInteger: ...
	def UMultiplicity(self, UIndex: int) -> int: ...
	def UReverse(self) -> None: ...
	def UReversedParameter(self, U: float) -> float: ...
	def VDegree(self) -> int: ...
	@overload
	def VIso(self, V: float) -> Geom_Curve: ...
	@overload
	def VIso(self, V: float, CheckRational: bool) -> Geom_Curve: ...
	def VKnot(self, VIndex: int) -> float: ...
	def VKnotDistribution(self) -> GeomAbs_BSplKnotDistribution: ...
	@overload
	def VKnotSequence(self, Kv: TColStd_Array1OfReal) -> None: ...
	@overload
	def VKnotSequence(self) -> TColStd_Array1OfReal: ...
	@overload
	def VKnots(self, Kv: TColStd_Array1OfReal) -> None: ...
	@overload
	def VKnots(self) -> TColStd_Array1OfReal: ...
	@overload
	def VMultiplicities(self, Mv: TColStd_Array1OfInteger) -> None: ...
	@overload
	def VMultiplicities(self) -> TColStd_Array1OfInteger: ...
	def VMultiplicity(self, VIndex: int) -> int: ...
	def VReverse(self) -> None: ...
	def VReversedParameter(self, V: float) -> float: ...
	def Weight(self, UIndex: int, VIndex: int) -> float: ...
	@overload
	def Weights(self, W: TColStd_Array2OfReal) -> None: ...
	@overload
	def Weights(self) -> TColStd_Array2OfReal: ...

class Geom_BezierCurve(Geom_BoundedCurve):
	@overload
	def __init__(self, CurvePoles: TColgp_Array1OfPnt) -> None: ...
	@overload
	def __init__(self, CurvePoles: TColgp_Array1OfPnt, PoleWeights: TColStd_Array1OfReal) -> None: ...
	def Continuity(self) -> GeomAbs_Shape: ...
	def Copy(self) -> Geom_Geometry: ...
	def D0(self, U: float, P: gp_Pnt) -> None: ...
	def D1(self, U: float, P: gp_Pnt, V1: gp_Vec) -> None: ...
	def D2(self, U: float, P: gp_Pnt, V1: gp_Vec, V2: gp_Vec) -> None: ...
	def D3(self, U: float, P: gp_Pnt, V1: gp_Vec, V2: gp_Vec, V3: gp_Vec) -> None: ...
	def DN(self, U: float, N: int) -> gp_Vec: ...
	def Degree(self) -> int: ...
	def EndPoint(self) -> gp_Pnt: ...
	def FirstParameter(self) -> float: ...
	def Increase(self, Degree: int) -> None: ...
	@overload
	def InsertPoleAfter(self, Index: int, P: gp_Pnt) -> None: ...
	@overload
	def InsertPoleAfter(self, Index: int, P: gp_Pnt, Weight: float) -> None: ...
	@overload
	def InsertPoleBefore(self, Index: int, P: gp_Pnt) -> None: ...
	@overload
	def InsertPoleBefore(self, Index: int, P: gp_Pnt, Weight: float) -> None: ...
	def IsCN(self, N: int) -> bool: ...
	def IsClosed(self) -> bool: ...
	def IsPeriodic(self) -> bool: ...
	def IsRational(self) -> bool: ...
	def LastParameter(self) -> float: ...
	@staticmethod
	def MaxDegree() -> int: ...
	def NbPoles(self) -> int: ...
	def Pole(self, Index: int) -> gp_Pnt: ...
	@overload
	def Poles(self, P: TColgp_Array1OfPnt) -> None: ...
	@overload
	def Poles(self) -> TColgp_Array1OfPnt: ...
	def RemovePole(self, Index: int) -> None: ...
	def Resolution(self, Tolerance3D: float) -> float: ...
	def Reverse(self) -> None: ...
	def ReversedParameter(self, U: float) -> float: ...
	def Segment(self, U1: float, U2: float) -> None: ...
	@overload
	def SetPole(self, Index: int, P: gp_Pnt) -> None: ...
	@overload
	def SetPole(self, Index: int, P: gp_Pnt, Weight: float) -> None: ...
	def SetWeight(self, Index: int, Weight: float) -> None: ...
	def StartPoint(self) -> gp_Pnt: ...
	def Transform(self, T: gp_Trsf) -> None: ...
	def Weight(self, Index: int) -> float: ...
	@overload
	def Weights(self, W: TColStd_Array1OfReal) -> None: ...
	@overload
	def Weights(self) -> TColStd_Array1OfReal: ...

class Geom_BezierSurface(Geom_BoundedSurface):
	@overload
	def __init__(self, SurfacePoles: TColgp_Array2OfPnt) -> None: ...
	@overload
	def __init__(self, SurfacePoles: TColgp_Array2OfPnt, PoleWeights: TColStd_Array2OfReal) -> None: ...
	def Bounds(self) -> Tuple[float, float, float, float]: ...
	def Continuity(self) -> GeomAbs_Shape: ...
	def Copy(self) -> Geom_Geometry: ...
	def D0(self, U: float, V: float, P: gp_Pnt) -> None: ...
	def D1(self, U: float, V: float, P: gp_Pnt, D1U: gp_Vec, D1V: gp_Vec) -> None: ...
	def D2(self, U: float, V: float, P: gp_Pnt, D1U: gp_Vec, D1V: gp_Vec, D2U: gp_Vec, D2V: gp_Vec, D2UV: gp_Vec) -> None: ...
	def D3(self, U: float, V: float, P: gp_Pnt, D1U: gp_Vec, D1V: gp_Vec, D2U: gp_Vec, D2V: gp_Vec, D2UV: gp_Vec, D3U: gp_Vec, D3V: gp_Vec, D3UUV: gp_Vec, D3UVV: gp_Vec) -> None: ...
	def DN(self, U: float, V: float, Nu: int, Nv: int) -> gp_Vec: ...
	def ExchangeUV(self) -> None: ...
	def Increase(self, UDeg: int, VDeg: int) -> None: ...
	@overload
	def InsertPoleColAfter(self, VIndex: int, CPoles: TColgp_Array1OfPnt) -> None: ...
	@overload
	def InsertPoleColAfter(self, VIndex: int, CPoles: TColgp_Array1OfPnt, CPoleWeights: TColStd_Array1OfReal) -> None: ...
	@overload
	def InsertPoleColBefore(self, VIndex: int, CPoles: TColgp_Array1OfPnt) -> None: ...
	@overload
	def InsertPoleColBefore(self, VIndex: int, CPoles: TColgp_Array1OfPnt, CPoleWeights: TColStd_Array1OfReal) -> None: ...
	@overload
	def InsertPoleRowAfter(self, UIndex: int, CPoles: TColgp_Array1OfPnt) -> None: ...
	@overload
	def InsertPoleRowAfter(self, UIndex: int, CPoles: TColgp_Array1OfPnt, CPoleWeights: TColStd_Array1OfReal) -> None: ...
	@overload
	def InsertPoleRowBefore(self, UIndex: int, CPoles: TColgp_Array1OfPnt) -> None: ...
	@overload
	def InsertPoleRowBefore(self, UIndex: int, CPoles: TColgp_Array1OfPnt, CPoleWeights: TColStd_Array1OfReal) -> None: ...
	def IsCNu(self, N: int) -> bool: ...
	def IsCNv(self, N: int) -> bool: ...
	def IsUClosed(self) -> bool: ...
	def IsUPeriodic(self) -> bool: ...
	def IsURational(self) -> bool: ...
	def IsVClosed(self) -> bool: ...
	def IsVPeriodic(self) -> bool: ...
	def IsVRational(self) -> bool: ...
	@staticmethod
	def MaxDegree() -> int: ...
	def NbUPoles(self) -> int: ...
	def NbVPoles(self) -> int: ...
	def Pole(self, UIndex: int, VIndex: int) -> gp_Pnt: ...
	@overload
	def Poles(self, P: TColgp_Array2OfPnt) -> None: ...
	@overload
	def Poles(self) -> TColgp_Array2OfPnt: ...
	def RemovePoleCol(self, VIndex: int) -> None: ...
	def RemovePoleRow(self, UIndex: int) -> None: ...
	def Resolution(self, Tolerance3D: float) -> Tuple[float, float]: ...
	def Segment(self, U1: float, U2: float, V1: float, V2: float) -> None: ...
	@overload
	def SetPole(self, UIndex: int, VIndex: int, P: gp_Pnt) -> None: ...
	@overload
	def SetPole(self, UIndex: int, VIndex: int, P: gp_Pnt, Weight: float) -> None: ...
	@overload
	def SetPoleCol(self, VIndex: int, CPoles: TColgp_Array1OfPnt) -> None: ...
	@overload
	def SetPoleCol(self, VIndex: int, CPoles: TColgp_Array1OfPnt, CPoleWeights: TColStd_Array1OfReal) -> None: ...
	@overload
	def SetPoleRow(self, UIndex: int, CPoles: TColgp_Array1OfPnt) -> None: ...
	@overload
	def SetPoleRow(self, UIndex: int, CPoles: TColgp_Array1OfPnt, CPoleWeights: TColStd_Array1OfReal) -> None: ...
	def SetWeight(self, UIndex: int, VIndex: int, Weight: float) -> None: ...
	def SetWeightCol(self, VIndex: int, CPoleWeights: TColStd_Array1OfReal) -> None: ...
	def SetWeightRow(self, UIndex: int, CPoleWeights: TColStd_Array1OfReal) -> None: ...
	def Transform(self, T: gp_Trsf) -> None: ...
	def UDegree(self) -> int: ...
	def UIso(self, U: float) -> Geom_Curve: ...
	def UReverse(self) -> None: ...
	def UReversedParameter(self, U: float) -> float: ...
	def VDegree(self) -> int: ...
	def VIso(self, V: float) -> Geom_Curve: ...
	def VReverse(self) -> None: ...
	def VReversedParameter(self, V: float) -> float: ...
	def Weight(self, UIndex: int, VIndex: int) -> float: ...
	@overload
	def Weights(self, W: TColStd_Array2OfReal) -> None: ...
	@overload
	def Weights(self) -> TColStd_Array2OfReal: ...

class Geom_Circle(Geom_Conic):
	@overload
	def __init__(self, C: gp_Circ) -> None: ...
	@overload
	def __init__(self, A2: gp_Ax2, Radius: float) -> None: ...
	def Circ(self) -> gp_Circ: ...
	def Copy(self) -> Geom_Geometry: ...
	def D0(self, U: float, P: gp_Pnt) -> None: ...
	def D1(self, U: float, P: gp_Pnt, V1: gp_Vec) -> None: ...
	def D2(self, U: float, P: gp_Pnt, V1: gp_Vec, V2: gp_Vec) -> None: ...
	def D3(self, U: float, P: gp_Pnt, V1: gp_Vec, V2: gp_Vec, V3: gp_Vec) -> None: ...
	def DN(self, U: float, N: int) -> gp_Vec: ...
	def Eccentricity(self) -> float: ...
	def FirstParameter(self) -> float: ...
	def IsClosed(self) -> bool: ...
	def IsPeriodic(self) -> bool: ...
	def LastParameter(self) -> float: ...
	def Radius(self) -> float: ...
	def ReversedParameter(self, U: float) -> float: ...
	def SetCirc(self, C: gp_Circ) -> None: ...
	def SetRadius(self, R: float) -> None: ...
	def Transform(self, T: gp_Trsf) -> None: ...

class Geom_ConicalSurface(Geom_ElementarySurface):
	@overload
	def __init__(self, A3: gp_Ax3, Ang: float, Radius: float) -> None: ...
	@overload
	def __init__(self, C: gp_Cone) -> None: ...
	def Apex(self) -> gp_Pnt: ...
	def Bounds(self) -> Tuple[float, float, float, float]: ...
	def Coefficients(self) -> Tuple[float, float, float, float, float, float, float, float, float, float]: ...
	def Cone(self) -> gp_Cone: ...
	def Copy(self) -> Geom_Geometry: ...
	def D0(self, U: float, V: float, P: gp_Pnt) -> None: ...
	def D1(self, U: float, V: float, P: gp_Pnt, D1U: gp_Vec, D1V: gp_Vec) -> None: ...
	def D2(self, U: float, V: float, P: gp_Pnt, D1U: gp_Vec, D1V: gp_Vec, D2U: gp_Vec, D2V: gp_Vec, D2UV: gp_Vec) -> None: ...
	def D3(self, U: float, V: float, P: gp_Pnt, D1U: gp_Vec, D1V: gp_Vec, D2U: gp_Vec, D2V: gp_Vec, D2UV: gp_Vec, D3U: gp_Vec, D3V: gp_Vec, D3UUV: gp_Vec, D3UVV: gp_Vec) -> None: ...
	def DN(self, U: float, V: float, Nu: int, Nv: int) -> gp_Vec: ...
	def IsUClosed(self) -> bool: ...
	def IsUPeriodic(self) -> bool: ...
	def IsVClosed(self) -> bool: ...
	def IsVPeriodic(self) -> bool: ...
	def ParametricTransformation(self, T: gp_Trsf) -> gp_GTrsf2d: ...
	def RefRadius(self) -> float: ...
	def SemiAngle(self) -> float: ...
	def SetCone(self, C: gp_Cone) -> None: ...
	def SetRadius(self, R: float) -> None: ...
	def SetSemiAngle(self, Ang: float) -> None: ...
	def Transform(self, T: gp_Trsf) -> None: ...
	def TransformParameters(self, T: gp_Trsf) -> Tuple[float, float]: ...
	def UIso(self, U: float) -> Geom_Curve: ...
	def UReversedParameter(self, U: float) -> float: ...
	def VIso(self, V: float) -> Geom_Curve: ...
	def VReverse(self) -> None: ...
	def VReversedParameter(self, V: float) -> float: ...

class Geom_CylindricalSurface(Geom_ElementarySurface):
	@overload
	def __init__(self, A3: gp_Ax3, Radius: float) -> None: ...
	@overload
	def __init__(self, C: gp_Cylinder) -> None: ...
	def Bounds(self) -> Tuple[float, float, float, float]: ...
	def Coefficients(self) -> Tuple[float, float, float, float, float, float, float, float, float, float]: ...
	def Copy(self) -> Geom_Geometry: ...
	def Cylinder(self) -> gp_Cylinder: ...
	def D0(self, U: float, V: float, P: gp_Pnt) -> None: ...
	def D1(self, U: float, V: float, P: gp_Pnt, D1U: gp_Vec, D1V: gp_Vec) -> None: ...
	def D2(self, U: float, V: float, P: gp_Pnt, D1U: gp_Vec, D1V: gp_Vec, D2U: gp_Vec, D2V: gp_Vec, D2UV: gp_Vec) -> None: ...
	def D3(self, U: float, V: float, P: gp_Pnt, D1U: gp_Vec, D1V: gp_Vec, D2U: gp_Vec, D2V: gp_Vec, D2UV: gp_Vec, D3U: gp_Vec, D3V: gp_Vec, D3UUV: gp_Vec, D3UVV: gp_Vec) -> None: ...
	def DN(self, U: float, V: float, Nu: int, Nv: int) -> gp_Vec: ...
	def IsUClosed(self) -> bool: ...
	def IsUPeriodic(self) -> bool: ...
	def IsVClosed(self) -> bool: ...
	def IsVPeriodic(self) -> bool: ...
	def ParametricTransformation(self, T: gp_Trsf) -> gp_GTrsf2d: ...
	def Radius(self) -> float: ...
	def SetCylinder(self, C: gp_Cylinder) -> None: ...
	def SetRadius(self, R: float) -> None: ...
	def Transform(self, T: gp_Trsf) -> None: ...
	def TransformParameters(self, T: gp_Trsf) -> Tuple[float, float]: ...
	def UIso(self, U: float) -> Geom_Curve: ...
	def UReversedParameter(self, U: float) -> float: ...
	def VIso(self, V: float) -> Geom_Curve: ...
	def VReversedParameter(self, V: float) -> float: ...

class Geom_Ellipse(Geom_Conic):
	@overload
	def __init__(self, E: gp_Elips) -> None: ...
	@overload
	def __init__(self, A2: gp_Ax2, MajorRadius: float, MinorRadius: float) -> None: ...
	def Copy(self) -> Geom_Geometry: ...
	def D0(self, U: float, P: gp_Pnt) -> None: ...
	def D1(self, U: float, P: gp_Pnt, V1: gp_Vec) -> None: ...
	def D2(self, U: float, P: gp_Pnt, V1: gp_Vec, V2: gp_Vec) -> None: ...
	def D3(self, U: float, P: gp_Pnt, V1: gp_Vec, V2: gp_Vec, V3: gp_Vec) -> None: ...
	def DN(self, U: float, N: int) -> gp_Vec: ...
	def Directrix1(self) -> gp_Ax1: ...
	def Directrix2(self) -> gp_Ax1: ...
	def Eccentricity(self) -> float: ...
	def Elips(self) -> gp_Elips: ...
	def FirstParameter(self) -> float: ...
	def Focal(self) -> float: ...
	def Focus1(self) -> gp_Pnt: ...
	def Focus2(self) -> gp_Pnt: ...
	def IsClosed(self) -> bool: ...
	def IsPeriodic(self) -> bool: ...
	def LastParameter(self) -> float: ...
	def MajorRadius(self) -> float: ...
	def MinorRadius(self) -> float: ...
	def Parameter(self) -> float: ...
	def ReversedParameter(self, U: float) -> float: ...
	def SetElips(self, E: gp_Elips) -> None: ...
	def SetMajorRadius(self, MajorRadius: float) -> None: ...
	def SetMinorRadius(self, MinorRadius: float) -> None: ...
	def Transform(self, T: gp_Trsf) -> None: ...

class Geom_Hyperbola(Geom_Conic):
	@overload
	def __init__(self, H: gp_Hypr) -> None: ...
	@overload
	def __init__(self, A2: gp_Ax2, MajorRadius: float, MinorRadius: float) -> None: ...
	def Asymptote1(self) -> gp_Ax1: ...
	def Asymptote2(self) -> gp_Ax1: ...
	def ConjugateBranch1(self) -> gp_Hypr: ...
	def ConjugateBranch2(self) -> gp_Hypr: ...
	def Copy(self) -> Geom_Geometry: ...
	def D0(self, U: float, P: gp_Pnt) -> None: ...
	def D1(self, U: float, P: gp_Pnt, V1: gp_Vec) -> None: ...
	def D2(self, U: float, P: gp_Pnt, V1: gp_Vec, V2: gp_Vec) -> None: ...
	def D3(self, U: float, P: gp_Pnt, V1: gp_Vec, V2: gp_Vec, V3: gp_Vec) -> None: ...
	def DN(self, U: float, N: int) -> gp_Vec: ...
	def Directrix1(self) -> gp_Ax1: ...
	def Directrix2(self) -> gp_Ax1: ...
	def Eccentricity(self) -> float: ...
	def FirstParameter(self) -> float: ...
	def Focal(self) -> float: ...
	def Focus1(self) -> gp_Pnt: ...
	def Focus2(self) -> gp_Pnt: ...
	def Hypr(self) -> gp_Hypr: ...
	def IsClosed(self) -> bool: ...
	def IsPeriodic(self) -> bool: ...
	def LastParameter(self) -> float: ...
	def MajorRadius(self) -> float: ...
	def MinorRadius(self) -> float: ...
	def OtherBranch(self) -> gp_Hypr: ...
	def Parameter(self) -> float: ...
	def ReversedParameter(self, U: float) -> float: ...
	def SetHypr(self, H: gp_Hypr) -> None: ...
	def SetMajorRadius(self, MajorRadius: float) -> None: ...
	def SetMinorRadius(self, MinorRadius: float) -> None: ...
	def Transform(self, T: gp_Trsf) -> None: ...

class Geom_Parabola(Geom_Conic):
	@overload
	def __init__(self, Prb: gp_Parab) -> None: ...
	@overload
	def __init__(self, A2: gp_Ax2, Focal: float) -> None: ...
	@overload
	def __init__(self, D: gp_Ax1, F: gp_Pnt) -> None: ...
	def Copy(self) -> Geom_Geometry: ...
	def D0(self, U: float, P: gp_Pnt) -> None: ...
	def D1(self, U: float, P: gp_Pnt, V1: gp_Vec) -> None: ...
	def D2(self, U: float, P: gp_Pnt, V1: gp_Vec, V2: gp_Vec) -> None: ...
	def D3(self, U: float, P: gp_Pnt, V1: gp_Vec, V2: gp_Vec, V3: gp_Vec) -> None: ...
	def DN(self, U: float, N: int) -> gp_Vec: ...
	def Directrix(self) -> gp_Ax1: ...
	def Eccentricity(self) -> float: ...
	def FirstParameter(self) -> float: ...
	def Focal(self) -> float: ...
	def Focus(self) -> gp_Pnt: ...
	def IsClosed(self) -> bool: ...
	def IsPeriodic(self) -> bool: ...
	def LastParameter(self) -> float: ...
	def Parab(self) -> gp_Parab: ...
	def Parameter(self) -> float: ...
	def ParametricTransformation(self, T: gp_Trsf) -> float: ...
	def ReversedParameter(self, U: float) -> float: ...
	def SetFocal(self, Focal: float) -> None: ...
	def SetParab(self, Prb: gp_Parab) -> None: ...
	def Transform(self, T: gp_Trsf) -> None: ...
	def TransformedParameter(self, U: float, T: gp_Trsf) -> float: ...

class Geom_Plane(Geom_ElementarySurface):
	@overload
	def __init__(self, A3: gp_Ax3) -> None: ...
	@overload
	def __init__(self, Pl: gp_Pln) -> None: ...
	@overload
	def __init__(self, P: gp_Pnt, V: gp_Dir) -> None: ...
	@overload
	def __init__(self, A: float, B: float, C: float, D: float) -> None: ...
	def Bounds(self) -> Tuple[float, float, float, float]: ...
	def Coefficients(self) -> Tuple[float, float, float, float]: ...
	def Copy(self) -> Geom_Geometry: ...
	def D0(self, U: float, V: float, P: gp_Pnt) -> None: ...
	def D1(self, U: float, V: float, P: gp_Pnt, D1U: gp_Vec, D1V: gp_Vec) -> None: ...
	def D2(self, U: float, V: float, P: gp_Pnt, D1U: gp_Vec, D1V: gp_Vec, D2U: gp_Vec, D2V: gp_Vec, D2UV: gp_Vec) -> None: ...
	def D3(self, U: float, V: float, P: gp_Pnt, D1U: gp_Vec, D1V: gp_Vec, D2U: gp_Vec, D2V: gp_Vec, D2UV: gp_Vec, D3U: gp_Vec, D3V: gp_Vec, D3UUV: gp_Vec, D3UVV: gp_Vec) -> None: ...
	def DN(self, U: float, V: float, Nu: int, Nv: int) -> gp_Vec: ...
	def IsUClosed(self) -> bool: ...
	def IsUPeriodic(self) -> bool: ...
	def IsVClosed(self) -> bool: ...
	def IsVPeriodic(self) -> bool: ...
	def ParametricTransformation(self, T: gp_Trsf) -> gp_GTrsf2d: ...
	def Pln(self) -> gp_Pln: ...
	def SetPln(self, Pl: gp_Pln) -> None: ...
	def Transform(self, T: gp_Trsf) -> None: ...
	def TransformParameters(self, T: gp_Trsf) -> Tuple[float, float]: ...
	def UIso(self, U: float) -> Geom_Curve: ...
	def UReverse(self) -> None: ...
	def UReversedParameter(self, U: float) -> float: ...
	def VIso(self, V: float) -> Geom_Curve: ...
	def VReverse(self) -> None: ...
	def VReversedParameter(self, V: float) -> float: ...

class Geom_RectangularTrimmedSurface(Geom_BoundedSurface):
	@overload
	def __init__(self, S: Geom_Surface, U1: float, U2: float, V1: float, V2: float, USense: Optional[bool] = True, VSense: Optional[bool] = True) -> None: ...
	@overload
	def __init__(self, S: Geom_Surface, Param1: float, Param2: float, UTrim: bool, Sense: Optional[bool] = True) -> None: ...
	def BasisSurface(self) -> Geom_Surface: ...
	def Bounds(self) -> Tuple[float, float, float, float]: ...
	def Continuity(self) -> GeomAbs_Shape: ...
	def Copy(self) -> Geom_Geometry: ...
	def D0(self, U: float, V: float, P: gp_Pnt) -> None: ...
	def D1(self, U: float, V: float, P: gp_Pnt, D1U: gp_Vec, D1V: gp_Vec) -> None: ...
	def D2(self, U: float, V: float, P: gp_Pnt, D1U: gp_Vec, D1V: gp_Vec, D2U: gp_Vec, D2V: gp_Vec, D2UV: gp_Vec) -> None: ...
	def D3(self, U: float, V: float, P: gp_Pnt, D1U: gp_Vec, D1V: gp_Vec, D2U: gp_Vec, D2V: gp_Vec, D2UV: gp_Vec, D3U: gp_Vec, D3V: gp_Vec, D3UUV: gp_Vec, D3UVV: gp_Vec) -> None: ...
	def DN(self, U: float, V: float, Nu: int, Nv: int) -> gp_Vec: ...
	def IsCNu(self, N: int) -> bool: ...
	def IsCNv(self, N: int) -> bool: ...
	def IsUClosed(self) -> bool: ...
	def IsUPeriodic(self) -> bool: ...
	def IsVClosed(self) -> bool: ...
	def IsVPeriodic(self) -> bool: ...
	def ParametricTransformation(self, T: gp_Trsf) -> gp_GTrsf2d: ...
	@overload
	def SetTrim(self, U1: float, U2: float, V1: float, V2: float, USense: Optional[bool] = True, VSense: Optional[bool] = True) -> None: ...
	@overload
	def SetTrim(self, Param1: float, Param2: float, UTrim: bool, Sense: Optional[bool] = True) -> None: ...
	def Transform(self, T: gp_Trsf) -> None: ...
	def TransformParameters(self, T: gp_Trsf) -> Tuple[float, float]: ...
	def UIso(self, U: float) -> Geom_Curve: ...
	def UPeriod(self) -> float: ...
	def UReverse(self) -> None: ...
	def UReversedParameter(self, U: float) -> float: ...
	def VIso(self, V: float) -> Geom_Curve: ...
	def VPeriod(self) -> float: ...
	def VReverse(self) -> None: ...
	def VReversedParameter(self, V: float) -> float: ...

class Geom_SphericalSurface(Geom_ElementarySurface):
	@overload
	def __init__(self, A3: gp_Ax3, Radius: float) -> None: ...
	@overload
	def __init__(self, S: gp_Sphere) -> None: ...
	def Area(self) -> float: ...
	def Bounds(self) -> Tuple[float, float, float, float]: ...
	def Coefficients(self) -> Tuple[float, float, float, float, float, float, float, float, float, float]: ...
	def Copy(self) -> Geom_Geometry: ...
	def D0(self, U: float, V: float, P: gp_Pnt) -> None: ...
	def D1(self, U: float, V: float, P: gp_Pnt, D1U: gp_Vec, D1V: gp_Vec) -> None: ...
	def D2(self, U: float, V: float, P: gp_Pnt, D1U: gp_Vec, D1V: gp_Vec, D2U: gp_Vec, D2V: gp_Vec, D2UV: gp_Vec) -> None: ...
	def D3(self, U: float, V: float, P: gp_Pnt, D1U: gp_Vec, D1V: gp_Vec, D2U: gp_Vec, D2V: gp_Vec, D2UV: gp_Vec, D3U: gp_Vec, D3V: gp_Vec, D3UUV: gp_Vec, D3UVV: gp_Vec) -> None: ...
	def DN(self, U: float, V: float, Nu: int, Nv: int) -> gp_Vec: ...
	def IsUClosed(self) -> bool: ...
	def IsUPeriodic(self) -> bool: ...
	def IsVClosed(self) -> bool: ...
	def IsVPeriodic(self) -> bool: ...
	def Radius(self) -> float: ...
	def SetRadius(self, R: float) -> None: ...
	def SetSphere(self, S: gp_Sphere) -> None: ...
	def Sphere(self) -> gp_Sphere: ...
	def Transform(self, T: gp_Trsf) -> None: ...
	def UIso(self, U: float) -> Geom_Curve: ...
	def UReversedParameter(self, U: float) -> float: ...
	def VIso(self, V: float) -> Geom_Curve: ...
	def VReversedParameter(self, V: float) -> float: ...
	def Volume(self) -> float: ...

class Geom_SurfaceOfLinearExtrusion(Geom_SweptSurface):
	def __init__(self, C: Geom_Curve, V: gp_Dir) -> None: ...
	def Bounds(self) -> Tuple[float, float, float, float]: ...
	def Copy(self) -> Geom_Geometry: ...
	def D0(self, U: float, V: float, P: gp_Pnt) -> None: ...
	def D1(self, U: float, V: float, P: gp_Pnt, D1U: gp_Vec, D1V: gp_Vec) -> None: ...
	def D2(self, U: float, V: float, P: gp_Pnt, D1U: gp_Vec, D1V: gp_Vec, D2U: gp_Vec, D2V: gp_Vec, D2UV: gp_Vec) -> None: ...
	def D3(self, U: float, V: float, P: gp_Pnt, D1U: gp_Vec, D1V: gp_Vec, D2U: gp_Vec, D2V: gp_Vec, D2UV: gp_Vec, D3U: gp_Vec, D3V: gp_Vec, D3UUV: gp_Vec, D3UVV: gp_Vec) -> None: ...
	def DN(self, U: float, V: float, Nu: int, Nv: int) -> gp_Vec: ...
	def IsCNu(self, N: int) -> bool: ...
	def IsCNv(self, N: int) -> bool: ...
	def IsUClosed(self) -> bool: ...
	def IsUPeriodic(self) -> bool: ...
	def IsVClosed(self) -> bool: ...
	def IsVPeriodic(self) -> bool: ...
	def ParametricTransformation(self, T: gp_Trsf) -> gp_GTrsf2d: ...
	def SetBasisCurve(self, C: Geom_Curve) -> None: ...
	def SetDirection(self, V: gp_Dir) -> None: ...
	def Transform(self, T: gp_Trsf) -> None: ...
	def TransformParameters(self, T: gp_Trsf) -> Tuple[float, float]: ...
	def UIso(self, U: float) -> Geom_Curve: ...
	def UReverse(self) -> None: ...
	def UReversedParameter(self, U: float) -> float: ...
	def VIso(self, V: float) -> Geom_Curve: ...
	def VReverse(self) -> None: ...
	def VReversedParameter(self, V: float) -> float: ...

class Geom_SurfaceOfRevolution(Geom_SweptSurface):
	def __init__(self, C: Geom_Curve, A1: gp_Ax1) -> None: ...
	def Axis(self) -> gp_Ax1: ...
	def Bounds(self) -> Tuple[float, float, float, float]: ...
	def Copy(self) -> Geom_Geometry: ...
	def D0(self, U: float, V: float, P: gp_Pnt) -> None: ...
	def D1(self, U: float, V: float, P: gp_Pnt, D1U: gp_Vec, D1V: gp_Vec) -> None: ...
	def D2(self, U: float, V: float, P: gp_Pnt, D1U: gp_Vec, D1V: gp_Vec, D2U: gp_Vec, D2V: gp_Vec, D2UV: gp_Vec) -> None: ...
	def D3(self, U: float, V: float, P: gp_Pnt, D1U: gp_Vec, D1V: gp_Vec, D2U: gp_Vec, D2V: gp_Vec, D2UV: gp_Vec, D3U: gp_Vec, D3V: gp_Vec, D3UUV: gp_Vec, D3UVV: gp_Vec) -> None: ...
	def DN(self, U: float, V: float, Nu: int, Nv: int) -> gp_Vec: ...
	def IsCNu(self, N: int) -> bool: ...
	def IsCNv(self, N: int) -> bool: ...
	def IsUClosed(self) -> bool: ...
	def IsUPeriodic(self) -> bool: ...
	def IsVClosed(self) -> bool: ...
	def IsVPeriodic(self) -> bool: ...
	def Location(self) -> gp_Pnt: ...
	def ParametricTransformation(self, T: gp_Trsf) -> gp_GTrsf2d: ...
	def ReferencePlane(self) -> gp_Ax2: ...
	def SetAxis(self, A1: gp_Ax1) -> None: ...
	def SetBasisCurve(self, C: Geom_Curve) -> None: ...
	def SetDirection(self, V: gp_Dir) -> None: ...
	def SetLocation(self, P: gp_Pnt) -> None: ...
	def Transform(self, T: gp_Trsf) -> None: ...
	def TransformParameters(self, T: gp_Trsf) -> Tuple[float, float]: ...
	def UIso(self, U: float) -> Geom_Curve: ...
	def UReverse(self) -> None: ...
	def UReversedParameter(self, U: float) -> float: ...
	def VIso(self, V: float) -> Geom_Curve: ...
	def VReverse(self) -> None: ...
	def VReversedParameter(self, V: float) -> float: ...

class Geom_ToroidalSurface(Geom_ElementarySurface):
	@overload
	def __init__(self, A3: gp_Ax3, MajorRadius: float, MinorRadius: float) -> None: ...
	@overload
	def __init__(self, T: gp_Torus) -> None: ...
	def Area(self) -> float: ...
	def Bounds(self) -> Tuple[float, float, float, float]: ...
	def Coefficients(self, Coef: TColStd_Array1OfReal) -> None: ...
	def Copy(self) -> Geom_Geometry: ...
	def D0(self, U: float, V: float, P: gp_Pnt) -> None: ...
	def D1(self, U: float, V: float, P: gp_Pnt, D1U: gp_Vec, D1V: gp_Vec) -> None: ...
	def D2(self, U: float, V: float, P: gp_Pnt, D1U: gp_Vec, D1V: gp_Vec, D2U: gp_Vec, D2V: gp_Vec, D2UV: gp_Vec) -> None: ...
	def D3(self, U: float, V: float, P: gp_Pnt, D1U: gp_Vec, D1V: gp_Vec, D2U: gp_Vec, D2V: gp_Vec, D2UV: gp_Vec, D3U: gp_Vec, D3V: gp_Vec, D3UUV: gp_Vec, D3UVV: gp_Vec) -> None: ...
	def DN(self, U: float, V: float, Nu: int, Nv: int) -> gp_Vec: ...
	def IsUClosed(self) -> bool: ...
	def IsUPeriodic(self) -> bool: ...
	def IsVClosed(self) -> bool: ...
	def IsVPeriodic(self) -> bool: ...
	def MajorRadius(self) -> float: ...
	def MinorRadius(self) -> float: ...
	def SetMajorRadius(self, MajorRadius: float) -> None: ...
	def SetMinorRadius(self, MinorRadius: float) -> None: ...
	def SetTorus(self, T: gp_Torus) -> None: ...
	def Torus(self) -> gp_Torus: ...
	def Transform(self, T: gp_Trsf) -> None: ...
	def UIso(self, U: float) -> Geom_Curve: ...
	def UReversedParameter(self, U: float) -> float: ...
	def VIso(self, V: float) -> Geom_Curve: ...
	def VReversedParameter(self, U: float) -> float: ...
	def Volume(self) -> float: ...

class Geom_TrimmedCurve(Geom_BoundedCurve):
	def __init__(self, C: Geom_Curve, U1: float, U2: float, Sense: Optional[bool] = True, theAdjustPeriodic: Optional[bool] = True) -> None: ...
	def BasisCurve(self) -> Geom_Curve: ...
	def Continuity(self) -> GeomAbs_Shape: ...
	def Copy(self) -> Geom_Geometry: ...
	def D0(self, U: float, P: gp_Pnt) -> None: ...
	def D1(self, U: float, P: gp_Pnt, V1: gp_Vec) -> None: ...
	def D2(self, U: float, P: gp_Pnt, V1: gp_Vec, V2: gp_Vec) -> None: ...
	def D3(self, U: float, P: gp_Pnt, V1: gp_Vec, V2: gp_Vec, V3: gp_Vec) -> None: ...
	def DN(self, U: float, N: int) -> gp_Vec: ...
	def EndPoint(self) -> gp_Pnt: ...
	def FirstParameter(self) -> float: ...
	def IsCN(self, N: int) -> bool: ...
	def IsClosed(self) -> bool: ...
	def IsPeriodic(self) -> bool: ...
	def LastParameter(self) -> float: ...
	def ParametricTransformation(self, T: gp_Trsf) -> float: ...
	def Period(self) -> float: ...
	def Reverse(self) -> None: ...
	def ReversedParameter(self, U: float) -> float: ...
	def SetTrim(self, U1: float, U2: float, Sense: Optional[bool] = True, theAdjustPeriodic: Optional[bool] = True) -> None: ...
	def StartPoint(self) -> gp_Pnt: ...
	def Transform(self, T: gp_Trsf) -> None: ...
	def TransformedParameter(self, U: float, T: gp_Trsf) -> float: ...

# harray1 classes
# harray2 classes
# hsequence classes

class Geom_HSequenceOfBSplineSurface(Geom_SequenceOfBSplineSurface, Standard_Transient):
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, other: Geom_SequenceOfBSplineSurface) -> None: ...
    def Sequence(self) -> Geom_SequenceOfBSplineSurface: ...
    def Append(self, theSequence: Geom_SequenceOfBSplineSurface) -> None: ...


Geom_BSplineCurve_MaxDegree = Geom_BSplineCurve.MaxDegree
Geom_BSplineSurface_MaxDegree = Geom_BSplineSurface.MaxDegree
Geom_BezierCurve_MaxDegree = Geom_BezierCurve.MaxDegree
Geom_BezierSurface_MaxDegree = Geom_BezierSurface.MaxDegree



from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.TopoDS import *
from OCC.Core.gp import *
from OCC.Core.TopTools import *


class ChFi2d_ConstructionError(IntEnum):
	ChFi2d_NotPlanar: int = ...
	ChFi2d_NoFace: int = ...
	ChFi2d_InitialisationError: int = ...
	ChFi2d_ParametersError: int = ...
	ChFi2d_Ready: int = ...
	ChFi2d_IsDone: int = ...
	ChFi2d_ComputationError: int = ...
	ChFi2d_ConnexionError: int = ...
	ChFi2d_TangencyError: int = ...
	ChFi2d_FirstEdgeDegenerated: int = ...
	ChFi2d_LastEdgeDegenerated: int = ...
	ChFi2d_BothEdgesDegenerated: int = ...
	ChFi2d_NotAuthorized: int = ...
ChFi2d_NotPlanar = ChFi2d_ConstructionError.ChFi2d_NotPlanar
ChFi2d_NoFace = ChFi2d_ConstructionError.ChFi2d_NoFace
ChFi2d_InitialisationError = ChFi2d_ConstructionError.ChFi2d_InitialisationError
ChFi2d_ParametersError = ChFi2d_ConstructionError.ChFi2d_ParametersError
ChFi2d_Ready = ChFi2d_ConstructionError.ChFi2d_Ready
ChFi2d_IsDone = ChFi2d_ConstructionError.ChFi2d_IsDone
ChFi2d_ComputationError = ChFi2d_ConstructionError.ChFi2d_ComputationError
ChFi2d_ConnexionError = ChFi2d_ConstructionError.ChFi2d_ConnexionError
ChFi2d_TangencyError = ChFi2d_ConstructionError.ChFi2d_TangencyError
ChFi2d_FirstEdgeDegenerated = ChFi2d_ConstructionError.ChFi2d_FirstEdgeDegenerated
ChFi2d_LastEdgeDegenerated = ChFi2d_ConstructionError.ChFi2d_LastEdgeDegenerated
ChFi2d_BothEdgesDegenerated = ChFi2d_ConstructionError.ChFi2d_BothEdgesDegenerated
ChFi2d_NotAuthorized = ChFi2d_ConstructionError.ChFi2d_NotAuthorized

class chfi2d:
	pass

class ChFi2d_AnaFilletAlgo:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theWire: TopoDS_Wire, thePlane: gp_Pln) -> None: ...
	@overload
	def __init__(self, theEdge1: TopoDS_Edge, theEdge2: TopoDS_Edge, thePlane: gp_Pln) -> None: ...
	@overload
	def Init(self, theWire: TopoDS_Wire, thePlane: gp_Pln) -> None: ...
	@overload
	def Init(self, theEdge1: TopoDS_Edge, theEdge2: TopoDS_Edge, thePlane: gp_Pln) -> None: ...
	def Perform(self, radius: float) -> bool: ...
	def Result(self, e1: TopoDS_Edge, e2: TopoDS_Edge) -> TopoDS_Edge: ...

class ChFi2d_Builder:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, F: TopoDS_Face) -> None: ...
	@overload
	def AddChamfer(self, E1: TopoDS_Edge, E2: TopoDS_Edge, D1: float, D2: float) -> TopoDS_Edge: ...
	@overload
	def AddChamfer(self, E: TopoDS_Edge, V: TopoDS_Vertex, D: float, Ang: float) -> TopoDS_Edge: ...
	def AddFillet(self, V: TopoDS_Vertex, Radius: float) -> TopoDS_Edge: ...
	def BasisEdge(self, E: TopoDS_Edge) -> TopoDS_Edge: ...
	def ChamferEdges(self) -> TopTools_SequenceOfShape: ...
	def DescendantEdge(self, E: TopoDS_Edge) -> TopoDS_Edge: ...
	def FilletEdges(self) -> TopTools_SequenceOfShape: ...
	def HasDescendant(self, E: TopoDS_Edge) -> bool: ...
	@overload
	def Init(self, F: TopoDS_Face) -> None: ...
	@overload
	def Init(self, RefFace: TopoDS_Face, ModFace: TopoDS_Face) -> None: ...
	def IsModified(self, E: TopoDS_Edge) -> bool: ...
	@overload
	def ModifyChamfer(self, Chamfer: TopoDS_Edge, E1: TopoDS_Edge, E2: TopoDS_Edge, D1: float, D2: float) -> TopoDS_Edge: ...
	@overload
	def ModifyChamfer(self, Chamfer: TopoDS_Edge, E: TopoDS_Edge, D: float, Ang: float) -> TopoDS_Edge: ...
	def ModifyFillet(self, Fillet: TopoDS_Edge, Radius: float) -> TopoDS_Edge: ...
	def NbChamfer(self) -> int: ...
	def NbFillet(self) -> int: ...
	def RemoveChamfer(self, Chamfer: TopoDS_Edge) -> TopoDS_Vertex: ...
	def RemoveFillet(self, Fillet: TopoDS_Edge) -> TopoDS_Vertex: ...
	def Result(self) -> TopoDS_Face: ...
	def Status(self) -> ChFi2d_ConstructionError: ...

class ChFi2d_ChamferAPI:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theWire: TopoDS_Wire) -> None: ...
	@overload
	def __init__(self, theEdge1: TopoDS_Edge, theEdge2: TopoDS_Edge) -> None: ...
	@overload
	def Init(self, theWire: TopoDS_Wire) -> None: ...
	@overload
	def Init(self, theEdge1: TopoDS_Edge, theEdge2: TopoDS_Edge) -> None: ...
	def Perform(self) -> bool: ...
	def Result(self, theEdge1: TopoDS_Edge, theEdge2: TopoDS_Edge, theLength1: float, theLength2: float) -> TopoDS_Edge: ...

class ChFi2d_FilletAPI:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theWire: TopoDS_Wire, thePlane: gp_Pln) -> None: ...
	@overload
	def __init__(self, theEdge1: TopoDS_Edge, theEdge2: TopoDS_Edge, thePlane: gp_Pln) -> None: ...
	@overload
	def Init(self, theWire: TopoDS_Wire, thePlane: gp_Pln) -> None: ...
	@overload
	def Init(self, theEdge1: TopoDS_Edge, theEdge2: TopoDS_Edge, thePlane: gp_Pln) -> None: ...
	def NbResults(self, thePoint: gp_Pnt) -> int: ...
	def Perform(self, theRadius: float) -> bool: ...
	def Result(self, thePoint: gp_Pnt, theEdge1: TopoDS_Edge, theEdge2: TopoDS_Edge, iSolution: Optional[int] = -1) -> TopoDS_Edge: ...

class ChFi2d_FilletAlgo:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theWire: TopoDS_Wire, thePlane: gp_Pln) -> None: ...
	@overload
	def __init__(self, theEdge1: TopoDS_Edge, theEdge2: TopoDS_Edge, thePlane: gp_Pln) -> None: ...
	@overload
	def Init(self, theWire: TopoDS_Wire, thePlane: gp_Pln) -> None: ...
	@overload
	def Init(self, theEdge1: TopoDS_Edge, theEdge2: TopoDS_Edge, thePlane: gp_Pln) -> None: ...
	def NbResults(self, thePoint: gp_Pnt) -> int: ...
	def Perform(self, theRadius: float) -> bool: ...
	def Result(self, thePoint: gp_Pnt, theEdge1: TopoDS_Edge, theEdge2: TopoDS_Edge, iSolution: Optional[int] = -1) -> TopoDS_Edge: ...

# harray1 classes
# harray2 classes
# hsequence classes

